/***********************r************************************************************
****    Procedure para calculo do demonstrativo de resultado operacional       ******
*************************************************************************************

Criado em  : 06/2011
       Por : Luciana Corra

Descrio:

          - Com base nos dados parametrizados para a filial realiza apurao do
            resultado operacional da mesma, grava em tabelas especficas a fim de
            possibilitar a gerao de relatrios gerenciais a partir de dados
            previamente calculados.

Util :
       - Dir      : @C:\WEB_511\SQL\END_CONV\ORACLE\4420_GERSTPO_APURAC_RESOPERFILI.SQL

       - Erro     : raise_application_error(-20501, 'Mensagem', True);

       - Executa  : EXEC APURAC_RESOPERFILI('0000000123','01/07/2006','31/07/2006');
       - Arquivos : _0481, _0565, _596
       }
*/
CREATE OR REPLACE PROCEDURE APURAC_RESOPERFILI_DRF
                                (P_CDFILIAL       FILIAL.CDFILIAL%TYPE,
                                 P_DTINICIAL      IN DATE,
                                 P_DTFINAL        IN DATE,
                                 P_IDCONSANT      IN VARCHAR) /* CALCULA CONSUMO ANTERIOR */

IS
/************** Variveis que recebem parametrizaes*******************/

   V_CDGRUPPRODDRO   VARCHAR2(10);
   V_CDGRUPPRODDRL   VARCHAR2(10);
   V_CDGRUPPRODVEN   VARCHAR2(10);
   V_IDEFETIVOROP    VARCHAR2(1);
   V_IDCOMPRAROP     VARCHAR2(1);
   V_IDAJUSTEROP     VARCHAR2(1);

   V_IDIMPLANTROP    VARCHAR2(1);
   V_IDINVFINAROP    VARCHAR2(1);
   V_IDINVINICROP    VARCHAR2(1);
   V_IDRETIRADAROP   VARCHAR2(1);
   V_IDDESPDIVROP    VARCHAR2(1);
   V_IDDESPENTROP    VARCHAR2(1);
   V_IDDESPMOBROP    VARCHAR2(1);
   V_IDFATUROP       VARCHAR2(2);
   V_IDNFSAIDAROP    VARCHAR2(1);

   V_FILIALPAR       VARCHAR2(4);   /*Filial padro*/
   V_IDUTPADRROPFIL  VARCHAR2(1);   /*Filial padro*/
   V_IDUTPADRROP     VARCHAR2(1);   /*Filial padro*/

/***********************************************************************/

   V_NRAPURREL       VARCHAR2(20);
   V_CDPRODFIN       VARCHAR2(20);
   V_CDPRODINI       VARCHAR2(20);
   V_NRMOVIESTQ      VARCHAR2(20);
   V_DTLANCMOVI      DATE;
   V_DTLANCMOVIF     DATE;

   V_NRROPFILIAL     VARCHAR2(20);
   V_NRLANCROP       NUMBER;
   V_NRITLANCROP     VARCHAR2(20);
   V_NRSEQRELACIT    VARCHAR2(10);
   V_NRTIPOCUSTO     NUMBER;
   V_PRODUTO         VARCHAR2(20);
   V_NRSEQIT         VARCHAR2(10);
   V_CDFILISUBGR     VARCHAR2(04);
   V_CDFILISUBGR_DRL VARCHAR2(04);
   V_CDFILISUBGR_VEN VARCHAR2(04);     
   V_IDSERVRETROP    CHAR;
   V_IDSERVFATROP    CHAR;
   V_CDFILCENTROP    VARCHAR2(04);

   /*Variveis para calculo do consumo*/
   V_CONSUMO         FLOAT;
   V_NRCOUNT         FLOAT;
   V_NRCONS          FLOAT;
   V_VALOR           FLOAT;
   V_DTINICONS       DATE;

   V_NRMESCONSROP    NUMBER;
   V_IDPERCONSROP    CHAR;
   V_DTINICIO        DATE;
   V_DTINICIOST VARCHAR2(30);
   V_DTFINAL         DATE;

   V_DTFILIALROP     DATE;
   V_NRITEM          NUMBER;
   V_CDFILCENTPME    VARCHAR2(4);
   V_IDFILIALAGRROP  CHAR;

   V_IDFECHDIAROP    CHAR;
   V_APURCONS        VARCHAR2(10);
   V_DTLANCROP       DATE;
   V_DTLANCROP_AUX   DATE;
   V_NRROPFILINI     VARCHAR2(20);
   V_CDFILIALIT      VARCHAR2(04);
   V_NRLANCTONFIT    VARCHAR2(10);
   V_CDFISCALIT      CHAR;
   V_ULTLANCMOVIEST  VARCHAR2(20);
   V_VRCUSTLOGLAN    FLOAT;
   V_VRSEGULOGLAN    FLOAT;
   V_DTINIC          DATE;
   V_FILIAPURA       VARCHAR2(4);
   V_NRDIAS          FLOAT;
   V_DTPROCESSA      DATE;
   V_IDLANCDTMENFIL  VARCHAR2(2);
   V_PRIIMP          NUMBER;

   /* NOVAS VARIAVEIS INCLUDAS POR LUCIANA CORREA */
   V_IDTPAPURACAO    VARCHAR2(1);
   V_CONTADOR        NUMBER;
   V_NRITLANCROP_AUX NUMBER;
   V_TIPOVENDA       VARCHAR2(2);
   V_QTDECUPONS      FLOAT;
   V_QTPESSOAS       FLOAT;
   V_IDAPUCTPGROP    VARCHAR2(1);
   V_IDAPUMOCTPGROP  VARCHAR2(1);
   V_IDDESPMOBROPCTB VARCHAR2(1);
   V_DTFOLHA         DATE;
   V_CDEMPRESA       VARCHAR2(2);
   V_IDDTAPUCTPAGAR  VARCHAR2(30);
   V_IDAPUINVFILROP  VARCHAR2(1);
   V_IDAPURAINVCTPAGROP VARCHAR2(1);
   V_IDCONSPERRATFIL VARCHAR2(1);
   V_IDPERFIXIMPDRF  VARCHAR2(1);
   V_VRTOTIMPOSTO    FLOAT;
   V_VRCOFINS        FLOAT;
   V_VRPIS           FLOAT;
   V_CDLOJA          VARCHAR2(10);
   V_VALORTOTAL      FLOAT;
	
BEGIN
   V_CONSUMO    := 0;
   V_NRLANCROP  := 0;
   V_NRDIAS     := 0;

   /*Verifica parametrizao para gerao do ROP*/
   /* IDUTPADRROP = 'S' -->> utiliza parametrizao padro para todas as filiais */
   BEGIN
      SELECT IDUTPADRROP
      INTO V_IDUTPADRROP
      FROM PARAMGERAL G;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN BEGIN
         V_IDUTPADRROP     := NULL;
      END;
   END;

   BEGIN
      SELECT IDUTPADRROPFIL, CDFILCENTPME, IDTPAPURACAO, CDEMPRESA
      INTO V_IDUTPADRROPFIL, V_CDFILCENTPME, V_IDTPAPURACAO, V_CDEMPRESA
      FROM PARFILIALROP P, FILIAL F
      WHERE
         F.CDFILIAL    = P_CDFILIAL    AND
         P.CDFILIAL(+) = F.CDFILIAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN BEGIN
         V_IDUTPADRROPFIL := NULL;
         V_CDFILCENTPME   := NULL;
         V_IDTPAPURACAO   := '1'; /* 1-APURACAO DO DRO DO TECFOOD  2-APURACAO DO DRL DO FORSALE  3-APURACAO DE AMBOS */
         V_CDEMPRESA      := NULL;
      END;
   END;


   IF (V_IDUTPADRROP = 'S' OR V_IDUTPADRROPFIL = 'S') THEN
      V_FILIALPAR := 'P';
   ELSE
      IF V_CDFILCENTPME IS NULL THEN
         V_FILIALPAR := P_CDFILIAL;
      ELSE
         BEGIN
            SELECT IDFILIALAGRROP
            INTO V_IDFILIALAGRROP
            FROM PARFILIALROP
            WHERE CDFILIAL = V_CDFILCENTPME;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_IDFILIALAGRROP := 'N';
         END;
         IF V_IDFILIALAGRROP = 'S' THEN
            V_FILIALPAR := V_CDFILCENTPME;
         ELSE
            V_FILIALPAR := P_CDFILIAL;
         END IF;
      END IF;
   END IF;

   /* Busca a parametrizao do ROP para a filial */
   BEGIN
      SELECT
          CDGRUPPROD,   IDFATUROP,    IDEFETIVOROP, IDCOMPRAROP,IDNFSAIDAROP,
          IDINVINICROP, IDIMPLANTROP, IDINVFINAROP, IDAJUSTEROP, IDRETIRADAROP,
          IDDESPDIVROP, IDDESPMOBROP, IDDESPENTROP, IDSERVRETROP, IDSERVFATROP,
          NVL(NRMESCONSROP,1), NVL(IDPERCONSROP, 'N'), IDFECHDIAROP, CDGRUPPRODDRL, CDGRUPPRODVEN,
          IDTPAPURACAO, IDAPUCTPGROP, IDAPUMOCTPGROP, IDDESPMOBROPCTB, NVL(IDDTAPUCTPAGAR,'N'),
		  IDAPUINVFILROP, NVL(IDAPURAINVCTPAGROP,'N'), NVL(IDCONSPERRATFIL,'N'), NVL(IDPERFIXIMPDRF,'N')
      INTO   V_CDGRUPPRODDRO, V_IDFATUROP,     V_IDEFETIVOROP, V_IDCOMPRAROP, V_IDNFSAIDAROP,
             V_IDINVINICROP,  V_IDIMPLANTROP,  V_IDINVFINAROP, V_IDAJUSTEROP, V_IDRETIRADAROP,
             V_IDDESPDIVROP,  V_IDDESPMOBROP,  V_IDDESPENTROP, V_IDSERVRETROP,V_IDSERVFATROP,
             V_NRMESCONSROP,  V_IDPERCONSROP,  V_IDFECHDIAROP, V_CDGRUPPRODDRL, V_CDGRUPPRODVEN,
             V_IDTPAPURACAO, V_IDAPUCTPGROP, V_IDAPUMOCTPGROP, V_IDDESPMOBROPCTB, V_IDDTAPUCTPAGAR,
			 V_IDAPUINVFILROP, V_IDAPURAINVCTPAGROP, V_IDCONSPERRATFIL, V_IDPERFIXIMPDRF
      FROM PARFILIALROP P
      WHERE P.CDFILIAL = V_FILIALPAR;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN BEGIN
         V_CDGRUPPRODDRO  := NULL;    V_IDFATUROP      := NULL; V_IDEFETIVOROP       := NULL; V_IDCOMPRAROP     := NULL;
         V_IDNFSAIDAROP   := NULL;    V_IDINVINICROP   := NULL; V_IDIMPLANTROP       := NULL; V_IDINVFINAROP    := NULL;
         V_IDAJUSTEROP    := NULL;    V_IDRETIRADAROP  := NULL; V_IDDESPDIVROP       := NULL; V_IDDESPMOBROP    := NULL;
         V_IDDESPENTROP   := NULL;    V_IDSERVRETROP   := NULL; V_IDSERVFATROP       := NULL; V_NRMESCONSROP    := 1;
         V_IDPERCONSROP   := 'N';     V_IDFECHDIAROP   := 'N' ; V_CDGRUPPRODDRL      := NULL; V_CDGRUPPRODVEN   := NULL;
         V_IDTPAPURACAO   := '1';     V_IDAPUCTPGROP   := 'N';  V_IDAPUMOCTPGROP     := 'N';  V_IDDESPMOBROPCTB := 'N';
		 V_IDDTAPUCTPAGAR := 'BAIXA'; V_IDAPUINVFILROP := NULL; V_IDAPURAINVCTPAGROP := 'N';  V_IDCONSPERRATFIL := 'N';
		 V_IDPERFIXIMPDRF := 'N';
      END;
   END;

   /* Busca a parametrizao do tipo de custo, filial centralizadora e data de processamento da filial */
   BEGIN
      SELECT TO_NUMBER(NVL(CDTIPCUSTEST,'3')), CDFILCENTPME,
             DECODE(IDUTILDTPROC,'S', TRUNC(NVL(DTPROCESSA,SYSDATE)), TRUNC(SYSDATE))
        INTO V_NRTIPOCUSTO, V_CDFILCENTROP, V_DTPROCESSA
        FROM PARAMFILIAL P, FILIAL F, PARAMGERAL
       WHERE P.CDFILIAL = F.CDFILIAL
         AND F.CDFILIAL = P_CDFILIAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_NRTIPOCUSTO   := '3' ;
         V_CDFILCENTROP  := NULL;
         V_DTPROCESSA    := TRUNC(SYSDATE);
   END;

   /*Verifica se filial tem sub-grupo especfico ou padro considerando o sub-grupo do DRO */
   FOR C_FILGRUPO IN(SELECT DISTINCT CDFILISUBGR
                       FROM PRSUBGRPROD
                      WHERE CDGRUPPROD = V_CDGRUPPRODDRO
                      ORDER BY CDFILISUBGR ASC)LOOP

          IF C_FILGRUPO.CDFILISUBGR = P_CDFILIAL THEN
             V_CDFILISUBGR := P_CDFILIAL;
             EXIT;
          ELSE
             V_CDFILISUBGR := 'P';
          END IF;
   END LOOP;

   /*Verifica se filial tem sub-grupo especfico ou padro considerando o sub-grupo de materia prima do DRF */
   FOR C_FILGRUPO IN(SELECT DISTINCT CDFILISUBGR
                       FROM PRSUBGRPROD
                      WHERE CDGRUPPROD = V_CDGRUPPRODDRL
                      ORDER BY CDFILISUBGR ASC)LOOP

          IF C_FILGRUPO.CDFILISUBGR = P_CDFILIAL THEN
             V_CDFILISUBGR_DRL := P_CDFILIAL;
             EXIT;
          ELSE
             V_CDFILISUBGR_DRL := 'P';
          END IF;
   END LOOP;

   /*Verifica se filial tem sub-grupo especfico ou padro considerando o sub-grupo de produtos de vendas do DRF */
   FOR C_FILGRUPO IN(SELECT DISTINCT CDFILISUBGR
                       FROM PRSUBGRPROD
                      WHERE CDGRUPPROD = V_CDGRUPPRODVEN
                      ORDER BY CDFILISUBGR ASC)LOOP

          IF C_FILGRUPO.CDFILISUBGR = P_CDFILIAL THEN
             V_CDFILISUBGR_VEN := P_CDFILIAL;
             EXIT;
          ELSE
             V_CDFILISUBGR_VEN := 'P';
          END IF;
   END LOOP;


   /*Verifica se a data compreendida no perodo parametrizado j foi apurada*/
   IF P_IDCONSANT = 'N' THEN

      V_FILIAPURA := V_FILIALPAR;
      IF V_FILIAPURA = 'P' THEN
         V_FILIAPURA := P_CDFILIAL;
      END IF;

      BEGIN
         SELECT DTINIAPURACROP
           INTO V_DTINIC
           FROM APURACAOROP
          WHERE CDFILIAL = V_FILIAPURA;

      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_DTINIC   := P_DTINICIAL;
      END;

      IF NOT(V_DTINIC < P_DTINICIAL AND V_DTINIC IS NOT NULL) THEN
         V_DTINIC := P_DTINICIAL;
      END IF;

/*      raise_application_error(-20501, 'Mensagem'||V_DTINIC, True); */
      BEGIN
         SELECT NVL(IDLANCDTMENFIL,'N')
           INTO V_IDLANCDTMENFIL
           FROM PARAMFILIAL
          WHERE CDFILIAL = P_CDFILIAL;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_IDLANCDTMENFIL := 'N';
      END;

      IF NVL(V_IDLANCDTMENFIL,'N') = 'S' THEN
         BEGIN
            SELECT MAX(NRDIAS)
              INTO V_NRDIAS
              FROM (SELECT NRDIASENTRFIL NRDIAS
                      FROM PARAMFILIAL
                     WHERE CDFILIAL = P_CDFILIAL
                       AND NVL(IDLANCDTMENFIL,'N') = 'S'
                     UNION ALL
                    SELECT NRDIASSAIDFIL NRDIAS
                      FROM PARAMFILIAL
                     WHERE CDFILIAL = P_CDFILIAL
                       AND NVL(IDLANCDTMENFIL,'N') = 'S'
                     UNION ALL
                    SELECT NRDIASAJUSFIL NRDIAS
                      FROM PARAMFILIAL
                     WHERE CDFILIAL = P_CDFILIAL
                       AND NVL(IDLANCDTMENFIL,'N') = 'S') A;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRDIAS := 0;
         END;

      ELSE

         BEGIN
            SELECT MAX(NRDIAS)
              INTO V_NRDIAS
              FROM (SELECT NRDIASENTR NRDIAS
                      FROM PARAMESTOQUE
                     WHERE NVL(IDLANCDTMEN,'N') = 'S'
                     UNION ALL
                    SELECT NRDIASSAID NRDIAS
                      FROM PARAMESTOQUE
                     WHERE NVL(IDLANCDTMEN,'N') = 'S'
                     UNION ALL
                    SELECT NRDIASAJUS NRDIAS
                      FROM PARAMESTOQUE
                     WHERE NVL(IDLANCDTMEN,'N') = 'S')A;

         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NRDIAS := 0;
         END;

      END IF;

      IF (V_DTINIC >= V_DTPROCESSA - V_NRDIAS) THEN
         V_DTINIC := V_DTPROCESSA - V_NRDIAS;
      END IF;

      IF V_IDTPAPURACAO = '2' THEN

         FOR C_LANCROPFILI IN(SELECT CDFILIAL, NRROPFILIAL, NRLANCROP
                            FROM LANCROPFILIAL
                            WHERE CDFILIAL   =  P_CDFILIAL
                              AND DTLANCROP  >= V_DTINIC) LOOP

            DELETE ITRELACITROP
            WHERE CDFILIAL    = P_CDFILIAL  AND
                  NRLANCROP   = C_LANCROPFILI.NRLANCROP AND
                  NRROPFILIAL = C_LANCROPFILI.NRROPFILIAL;

            DELETE ITLANCROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL  AND
                  NRLANCROP   = C_LANCROPFILI.NRLANCROP AND
                  NRROPFILIAL = C_LANCROPFILI.NRROPFILIAL;

            DELETE LANCROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL  AND
                  NRLANCROP   = C_LANCROPFILI.NRLANCROP AND
                  NRROPFILIAL = C_LANCROPFILI.NRROPFILIAL;
         END LOOP;

         FOR C_ROPFILI IN(SELECT NRROPFILIAL
                            FROM ROPFILIAL
                            WHERE CDFILIAL     =  P_CDFILIAL AND
                                  DTFILIALROP  >= V_DTINIC) LOOP

            DELETE ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL  AND
                  NRROPFILIAL = C_ROPFILI.NRROPFILIAL;

         END LOOP;
      ELSE
         IF V_IDTPAPURACAO = '1' THEN
            raise_application_error(-20501, 'A filial no est configurada para apurar o resultado operacional da loja', True);
         END IF;
      END IF;

   ELSE
      V_DTINIC := P_DTINICIAL;
   END IF;

   V_DTFILIALROP := V_DTINIC;

   NOVO_CODIGO('RESULTOPER' || P_CDFILIAL, V_NRROPFILIAL, ROUND(TO_NUMBER(P_DTFINAL - V_DTINIC)+2,0));
   V_NRROPFILIAL := SUBSTR(V_NRROPFILIAL, 11, 10);
   V_NRROPFILINI := V_NRROPFILIAL;


   /*raise_application_error(-20501, 'Mensagem'||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI, True);*/

   WHILE (V_DTFILIALROP <= P_DTFINAL) LOOP

      INSERT INTO ROPFILIAL
         (CDFILIAL, NRROPFILIAL, DTINICROP, DTFINALROP, DTGERAROP, DTFILIALROP)
      VALUES
         (P_CDFILIAL, V_NRROPFILIAL, V_DTINIC, P_DTFINAL, SYSDATE, V_DTFILIALROP);

      /* DRF- Grava Posio Incial e Final para cada dia apurado - Invent.Inicial para o DRF -  diferente do DRO apenas pelo grupo de produtos usado */
      /* EST GRAVANDO PRODUTO A PRODUTO */
      IF (V_IDINVINICROP = 'S') AND (V_IDTPAPURACAO <> '1') THEN
         V_NRITLANCROP := '00000';

         FOR C_INVINICIAL IN(   SELECT AN.CDGRUPPROD, AN.CDSUBGRPROD, SUM(QTESTDIACON) AS QTESTDIACON, SUM(VRESTDIACON) AS VRESTDIACON
                                  FROM SUBGRPRODFIL SG, PRODUTO A,
                                   
								   ( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD ) AN,
                                   
								   (SELECT CDPRODUTO, QTESTOQDIA AS QTESTDIACON,
                                           NVL(CUSTO_PRODUTO_LCEST(B.CDFILIAL, B.CDPRODUTO, V_NRTIPOCUSTO, V_DTFILIALROP-1, SYSDATE, CDALMOXARIFE, CDLOCALESTOQ,  B.NRLOTEESTQ, B.NRSUBLOTE),0) *QTESTOQDIA AS VRESTDIACON
                                      FROM POSESTDIA B
                                     WHERE (B.CDFILIAL   = P_CDFILIAL)         AND
                                           (B.QTESTOQDIA  <> 0)              AND
                                           (B.DTPOSIESTQ =  (SELECT MAX(P.DTPOSIESTQ)
                                                              FROM POSESTDIA P
                                                             WHERE (P.CDFILIAL       = P_CDFILIAL)      AND
                                                                    (P.CDPRODUTO     = B.CDPRODUTO)     AND
                                                                    (P.CDALMOXARIFE  = B.CDALMOXARIFE)  AND
                                                                    (P.CDLOCALESTOQ  = B.CDLOCALESTOQ)  AND
                                                                    (P.NRLOTEESTQ    = B.NRLOTEESTQ)    AND
                                                                    (P.NRSUBLOTE     = B.NRSUBLOTE)     AND
                                                                    (P.DTPOSIESTQ    <= V_DTFILIALROP)))) P
                                WHERE
                                 (SG.CDFILISUBGR  = V_CDFILISUBGR_DRL) AND
                                 (SG.CDGRUPPROD   = V_CDGRUPPRODDRL ) AND
                                 (AN.CDFILISUBGR = SG.CDFILISUBGR)  AND
                                 (AN.CDGRUPPROD  = SG.CDGRUPPROD  ) AND
                                 (AN.CDSUBGRPROD = SG.CDSUBGRPROD)  AND
                                 (P.CDPRODUTO    = AN.CDPRODUTO)    AND
                                 (P.CDPRODUTO    = A.CDPRODUTO)     AND
                                 (A.CDPRODUTO    = A.CDPRODESTO)
                             GROUP BY AN.CDGRUPPROD, AN.CDSUBGRPROD
                             ORDER BY AN.CDGRUPPROD, AN.CDSUBGRPROD DESC) LOOP


            V_NRLANCROP := V_NRLANCROP + 1;
            /*Inclui Inventario Inicial*/
            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP )
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTFILIALROP, 'I1', '',
                '',  '', '', P_CDFILIAL,'', V_CDFILCENTROP);

            /*Inclui Item do Lanamento*/
            V_NRITLANCROP := '00001';

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP,
                CDGRUPPRODROP, CDSUBGRPRODROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, P_CDFILIAL, '',
                '', /*C_INVINICIAL.CDPRODUTO*/'',  C_INVINICIAL.QTESTDIACON, C_INVINICIAL.VRESTDIACON,
                C_INVINICIAL.CDGRUPPROD, C_INVINICIAL.CDSUBGRPROD );

            V_CONSUMO := V_CONSUMO + C_INVINICIAL.VRESTDIACON;

         END LOOP;
      END IF;

      /* DRF - Inventrio Final do DRF */
      IF (V_IDINVFINAROP = 'S') AND (V_IDTPAPURACAO <> '1') THEN
         V_NRITLANCROP := '00000';
         FOR C_INVFINAL IN(   SELECT AN.CDGRUPPROD, AN.CDSUBGRPROD, SUM(QTESTDIACON) AS QTESTDIACON, SUM(VRESTDIACON) AS VRESTDIACON
                                FROM SUBGRPRODFIL SG, PRODUTO A,
                                   
								   ( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD ) AN,
								   
								   (SELECT CDPRODUTO, QTESTOQDIA AS QTESTDIACON,
                                           NVL(CUSTO_PRODUTO_LCEST(B.CDFILIAL, B.CDPRODUTO, V_NRTIPOCUSTO, V_DTFILIALROP, SYSDATE, CDALMOXARIFE, CDLOCALESTOQ,  B.NRLOTEESTQ, B.NRSUBLOTE),0) *QTESTOQDIA AS VRESTDIACON
                                      FROM POSESTDIA B
                                     WHERE (B.CDFILIAL   = P_CDFILIAL)         AND
                                           (B.QTESTOQDIA  <> 0)              AND
                                           (B.DTPOSIESTQ =  (SELECT MAX(P.DTPOSIESTQ)
                                                              FROM POSESTDIA P
                                                             WHERE (P.CDFILIAL       = P_CDFILIAL)      AND
                                                                    (P.CDPRODUTO     = B.CDPRODUTO)     AND
                                                                    (P.CDALMOXARIFE  = B.CDALMOXARIFE)  AND
                                                                    (P.CDLOCALESTOQ  = B.CDLOCALESTOQ)  AND
                                                                    (P.NRLOTEESTQ    = B.NRLOTEESTQ)    AND
                                                                    (P.NRSUBLOTE     = B.NRSUBLOTE)     AND
                                                                    (P.DTPOSIESTQ    <= V_DTFILIALROP+1)))) P
                              WHERE
                                 (SG.CDFILISUBGR  = V_CDFILISUBGR_DRL)AND
                                 (SG.CDGRUPPROD   = V_CDGRUPPRODDRL  )AND
                                 (AN.CDFILISUBGR = SG.CDFILISUBGR)AND
                                 (AN.CDGRUPPROD = SG.CDGRUPPROD  )AND
                                 (AN.CDSUBGRPROD = SG.CDSUBGRPROD)AND
                                 (P.CDPRODUTO    = A.CDPRODUTO)   AND
                                 (P.CDPRODUTO     = AN.CDPRODUTO) AND
                                 (A.CDPRODUTO     = A.CDPRODESTO)
                             GROUP BY AN.CDGRUPPROD, AN.CDSUBGRPROD
                             ORDER BY AN.CDGRUPPROD, AN.CDSUBGRPROD DESC ) LOOP

            /*Inclui Inventario FINAL*/
            V_NRLANCROP := V_NRLANCROP + 1;
            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP )
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTFILIALROP, 'I2', '',
                '',  '', '', P_CDFILIAL,'', V_CDFILCENTROP);

            /*Inclui Item do Lanamento*/
            V_NRITLANCROP := '00001';

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP,
                CDGRUPPRODROP, CDSUBGRPRODROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, P_CDFILIAL, '',
                '', C_INVFINAL.CDSUBGRPROD,  C_INVFINAL.QTESTDIACON, C_INVFINAL.VRESTDIACON,
                C_INVFINAL.CDGRUPPROD, C_INVFINAL.CDSUBGRPROD);

            V_CONSUMO := V_CONSUMO - C_INVFINAL.VRESTDIACON;
         END LOOP;
      END IF;

      V_DTFILIALROP  := TRUNC(TO_DATE(V_DTFILIALROP+1));
      V_NRROPFILIAL  := LPAD(V_NRROPFILIAL + 1,10,'0');
   END LOOP;

   /* raise_application_error(-20501, 'Mensagem'||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI, True); */

   /* DRF - Clculo do Faturamento - Faturamento Bruto - Notas Fiscais de sada - SERVE PARA O DRF - FORSALE */
   IF (V_IDFATUROP = 'FS' OR V_IDFATUROP = 'AB') AND (V_IDTPAPURACAO <> '1') THEN
      V_DTLANCROP := '01/01/1990';
      FOR C_FATURANF IN(SELECT N.CDCLIENTE,    N.CDTIPOOPER, N.NRNOTAFISC, N.CDFILIAL,
                               N.NRLANCTONF,   N.DTENTRSAID, N.CDSERIE,    N.IDSTATUS,
                               N.DTINIREFEFAT, N.DTFINREFEFAT,
                               DECODE(IDSISTEMA, 'PDV', N.VRPRODUTOS, N.VRNOTAFISC) AS VALORTOTAL
                          FROM NOTAFISCAL N, TIPOOPERACROP P, (SELECT DTDATA DIA
                                                                 FROM DATA
                                                                WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                         WHERE (N.CDFILIEMIT     = P_CDFILIAL)
                           AND (N.IDENTRSAIDOP   = 'S')
                           AND (N.DTENTRSAID = D.DIA)
                           AND (V_FILIALPAR      = P.CDFILIAL)
                           AND (N.CDTIPOOPER     = P.CDTIPOOPER)
                           AND (N.IDENTRSAIDOP   = P.IDENTRSAIDOP)
                           AND (P.IDTPOPERACROP  = 'FN')
                           AND ((N.IDSTATUS    IN ('A','E','P')) OR (N.IDSISTEMA = 'PDV'))
                           AND (N.IDSISTEMA NOT IN ('REC','FIS') OR N.IDSISTEMA IS NULL)) LOOP

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_FATURANF.DTENTRSAID THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_FATURANF.DTENTRSAID;

            V_DTLANCROP   := C_FATURANF.DTENTRSAID;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

/*   raise_application_error(-20501, 'Mensagem'||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_FATURANF.DTENTRSAID, 'FN', C_FATURANF.CDCLIENTE,
             C_FATURANF.CDTIPOOPER,  C_FATURANF.NRNOTAFISC, C_FATURANF.CDSERIE, C_FATURANF.CDFILIAL,
             C_FATURANF.NRLANCTONF, V_CDFILCENTROP, C_FATURANF.IDSTATUS, C_FATURANF.DTINIREFEFAT,
             C_FATURANF.DTFINREFEFAT);

            /*Inclui Item do Lanamento*/
            V_NRITLANCROP := LPAD('00000' + 1,5,'0');

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP, VRITEMLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_FATURANF.CDFILIAL, C_FATURANF.NRLANCTONF,
                '', '',  0, C_FATURANF.VALORTOTAL);

         /*Imposto por Item NF */
         V_NRSEQRELACIT := 0;

         FOR C_IMPOSTO IN(SELECT P.CDIMPOSTO,
                                 SUM(VALOR_IMPOSTO_NF(C_FATURANF.CDFILIAL, C_FATURANF.NRLANCTONF, CDIMPOSTO,'I')) AS VRIMPOSTO
                            FROM IMPOSTOROP P
                           WHERE P.CDFILIAL      = V_FILIALPAR
                             AND IDTPIMPOSTOROP  = 'FN'
                           GROUP BY P.CDIMPOSTO
                           ORDER BY P.CDIMPOSTO)LOOP

            V_NRSEQRELACIT := V_NRSEQRELACIT + 1;

            INSERT INTO ITRELACITROP
               (CDFILIAL,  NRROPFILIAL, NRLANCROP, NRITLANCROP, NRSEQRELACITROP,
                CDITRELITROP, QTITRELITROP, VRITRELITROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, V_NRSEQRELACIT,
                C_IMPOSTO.CDIMPOSTO, 0,C_IMPOSTO.VRIMPOSTO);
         END LOOP;
      END LOOP;
   END IF;

   /*raise_application_error(-20501, 'Mensagem XX: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

   /* DRF - Parte especfica do ForSale */
   IF V_IDTPAPURACAO <> '1' THEN

      /* FATURAMENTO BRUTO - VENDAS REGISTRADAS PARA A FILIAL,LOJA E DATA */
      V_DTLANCROP := '01/01/1990';
      FOR C_VENDAS IN(SELECT V.CDFILIAL,V.CDLOJA, V.DTENTRVENDA,
                             SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) AS VALORTOTAL,
                             SUM(NVL(I.VRACRITVEND,0)) AS VRACRITVEND,
                             SUM(NVL(I.VRDESITVEND,0)) AS VRDESITVEND,
                             SUM(I.QTPRODVEND) AS QTVENDIDA,
                             SUM(CUSTO_COMPOSICAO(I.CDPRODUTO,V.CDFILIAL,V.CDFILIAL,V_NRTIPOCUSTO,I.QTPRODVEND,'',V.DTENTRVENDA)) AS VALORTOTAL_CUSTO,
                             SUM((TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) * P.VRPEALPRODIT / 100) AS VRIMPOSTO
							   FROM VENDA V, ITEMVENDA I, ITVENDAIMPOS P, (SELECT DTDATA DIA
                                                                      FROM DATA
                                                                     WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
						     WHERE (V.CDFILIAL    = P_CDFILIAL    )
							    AND (V.DTENTRVENDA = D.DIA)
						       AND (V.IDSITUVENDA = 'O'           )
							    AND (I.CDFILIAL    = V.CDFILIAL    )
							    AND (I.CDCAIXA     = V.CDCAIXA     )
							    AND (I.NRSEQVENDA  = V.NRSEQVENDA  )
							    AND (I.CDFILIAL    = P.CDFILIAL    )
                         AND (I.CDCAIXA     = P.CDCAIXA     )
                         AND (I.NRSEQVENDA  = P.NRSEQVENDA  )
                         AND (I.NRSEQUITVEND= P.NRSEQUITVEND)
                       GROUP BY V.CDFILIAL, V.CDLOJA, V.DTENTRVENDA) LOOP

         /* CALCULA A QUANTIDADE DE CUPONS PARA A FILIAL,LOJA E DATA */
         SELECT COUNT(*) INTO V_QTDECUPONS
         FROM   VENDA V
         WHERE V.CDFILIAL    = C_VENDAS.CDFILIAL
           AND V.DTENTRVENDA = C_VENDAS.DTENTRVENDA
           AND V.CDLOJA      = C_VENDAS.CDLOJA
           AND V.IDSITUVENDA = 'O';

         /* CALCULA A QUANTIDADE DE PESSOAS PARA A FILIAL,LOJA E DATA */
         BEGIN
            SELECT SUM(NVL(V.NRPESMESAVENDA,1)) INTO V_QTPESSOAS
            FROM   VENDA V
            WHERE V.CDFILIAL    = C_VENDAS.CDFILIAL
              AND V.DTENTRVENDA = C_VENDAS.DTENTRVENDA
              AND V.CDLOJA      = C_VENDAS.CDLOJA
              AND V.IDSITUVENDA = 'O';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN BEGIN
               V_QTPESSOAS := 1;
            END;
         END;
			
		 /* CALCULA O VALOR DOS IMPOSTOS PIS E COFINS PARA VENDAS SAT e NFC-e */
		 SELECT SUM(NVL(P.VRIMPPIS,0)), SUM(NVL(P.VRIMPCOFINS,0)) INTO V_VRPIS, V_VRCOFINS
		   FROM VENDA V, ITVENDAIMPOS P
		  WHERE V.CDFILIAL    = C_VENDAS.CDFILIAL
		    AND V.DTENTRVENDA = C_VENDAS.DTENTRVENDA
			AND V.CDLOJA      = C_VENDAS.CDLOJA
			AND V.IDSITUVENDA = 'O'
			AND V.IDTPEMISVEND IN ('S','N')
		    AND V.CDFILIAL    = P.CDFILIAL
			AND V.CDCAIXA     = P.CDCAIXA
			AND V.NRSEQVENDA  = P.NRSEQVENDA;

  /*       IF V_DTLANCROP <> C_VENDAS.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_VENDAS.DTENTRVENDA;

            V_DTLANCROP   := C_VENDAS.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;
         END IF;
    */
		 IF (V_IDPERFIXIMPDRF = 'S') THEN
			V_VRTOTIMPOSTO := 0;
		 ELSE
			V_VRTOTIMPOSTO := C_VENDAS.VRIMPOSTO + NVL(V_VRPIS,0) + NVL(V_VRCOFINS,0);
		 END IF;
         
		 V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_VENDAS.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_VENDAS.DTENTRVENDA;

            V_DTLANCROP   := C_VENDAS.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /* INCLUI A VENDA NA TABELA LANCROPFILIAL - FILIAL,CAIXA,SEQVENDA, NRCUPOM E VALORES TOTAIS */
         V_NRLANCROP := V_NRLANCROP + 1;

         /*raise_application_error(-20501, 'Mensagem'||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP, VRIMPLANCROP, NRPESLANCROP,NRCUPLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_VENDAS.DTENTRVENDA, 'FF', '',
             '',  '', '', C_VENDAS.CDFILIAL,'', '', '', '','','', C_VENDAS.CDLOJA,
             C_VENDAS.VRACRITVEND, C_VENDAS.VRDESITVEND, V_VRTOTIMPOSTO, V_QTPESSOAS, V_QTDECUPONS);

         /*Inclui Item do Lanamento*/
         V_NRITLANCROP := LPAD('00000' + 1,5,'0');

         /* INSERE UM REGISTRO COM TOTAIS DA VENDA, PRATICAMENTE REPETE OS VALORES DA LANCROPFILIAL. NO INSERE PRODUTO POR PRODUTO */
         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,  VRITEMLANCROP, VRACRITLANCROP, VRDESITLANCROP, VRIMPITLANCROP,VRCUSTSEGPROD,VRCUSTOLOGITROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_VENDAS.CDFILIAL, '',
             '', '',  C_VENDAS.QTVENDIDA, C_VENDAS.VALORTOTAL, C_VENDAS.VRACRITVEND, C_VENDAS.VRDESITVEND, V_VRTOTIMPOSTO, C_VENDAS.VALORTOTAL_CUSTO, C_VENDAS.VALORTOTAL_CUSTO);
			 
		 /* CONSIDERA PERCENTUAL FIXO PARA CLCULO DO IMPOSTO */
		 V_NRSEQRELACIT := 0;
		 
		 IF (V_IDPERFIXIMPDRF = 'S') THEN
			 FOR C_IMPOSTO IN(SELECT CDIMPOSTO, VRPERFIXCALCIMP, (C_VENDAS.VALORTOTAL * NVL(VRPERFIXCALCIMP,0)) / 100 AS VRIMPOSTO 
                                FROM IMPOSTOROP 
                               WHERE CDFILIAL       = V_FILIALPAR 
                                 AND IDTPIMPOSTOROP = 'FN' 
                              ORDER BY CDIMPOSTO) LOOP

				V_NRSEQRELACIT := V_NRSEQRELACIT + 1;

				INSERT INTO ITRELACITROP
				   (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, NRSEQRELACITROP,
					CDITRELITROP, QTITRELITROP, VRITRELITROP)
				VALUES
				   (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, V_NRSEQRELACIT,
					C_IMPOSTO.CDIMPOSTO, C_IMPOSTO.VRPERFIXCALCIMP, C_IMPOSTO.VRIMPOSTO);
             END LOOP;
		 END IF;
      END LOOP;
      /* FIM CLCULO DO FATURAMENTO BRUTO FORSALE ATRAVS DAS TABELAS DE VENDA PARA A FILIAL,LOJA E DATA*/


      /* DRF - CLCULO VENDAS CANCELADAS - PARA A FILIAL,LOJA E DATA */
      V_DTLANCROP := '01/01/1990';
      FOR C_VENDAS_CANC IN(SELECT V.CDFILIAL,V.CDLOJA, V.DTENTRVENDA,
                                  SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) AS VALORTOTAL,
                                  SUM(NVL(I.VRACRITVEND,0)) AS VRACRITVEND,
                                  SUM(NVL(I.VRDESITVEND,0)) AS VRDESITVEND,
                                  SUM(I.QTPRODVEND) AS QTVENDIDA,
                                  COUNT(DISTINCT V.CDFILIAL||V.CDCAIXA||V.NRSEQVENDA) AS QTCUPONS
                             FROM VENDA V, ITEMVENDA I, (SELECT DTDATA DIA
                                                           FROM DATA
                                                          WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                            WHERE (V.CDFILIAL    = P_CDFILIAL)
                              AND (V.DTENTRVENDA = D.DIA)
                              AND (V.CDFILIAL    = I.CDFILIAL(+))
                              AND (V.CDCAIXA     = I.CDCAIXA(+))
                              AND (V.NRSEQVENDA  = I.NRSEQVENDA(+))
                              AND (V.IDSITUVENDA = 'C')
                            GROUP BY V.CDFILIAL, V.CDLOJA, V.DTENTRVENDA) LOOP

         /*
         IF V_DTLANCROP <> C_VENDAS_CANC.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_VENDAS_CANC.DTENTRVENDA;

            V_DTLANCROP   := C_VENDAS_CANC.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;
         END IF; */

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_VENDAS_CANC.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_VENDAS_CANC.DTENTRVENDA;

            V_DTLANCROP   := C_VENDAS_CANC.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*INCLUI A VENDA NA TABELA LANCROPFILIAL - FILIAL,CAIXA,SEQVENDA, NRCUPOM E VALORES TOTAIS*/
         /*V_NRLANCROP := V_NRLANCROP + 1; */
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP, VRIMPLANCROP,NRCUPLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_VENDAS_CANC.DTENTRVENDA, 'C1', '',
             '',  '', '', C_VENDAS_CANC.CDFILIAL,'', V_CDFILCENTROP, '', '','','', C_VENDAS_CANC.CDLOJA,
             C_VENDAS_CANC.VRACRITVEND, C_VENDAS_CANC.VRDESITVEND, 0,C_VENDAS_CANC.QTCUPONS);

         /*INCLUI ITEM DO LANAMENTO*/
         V_NRITLANCROP := LPAD('00000' + 1,5,'0');

         /* INSERE UM REGISTRO COM TOTAIS DA VENDA, PRATICAMENTE REPETE OS VALORES DA LANCROPFILIAL. NO INSERE PRODUTO POR PRODUTO */
         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,  VRITEMLANCROP, VRACRITLANCROP, VRDESITLANCROP, VRIMPITLANCROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_VENDAS_CANC.CDFILIAL, '',
             '', '',  C_VENDAS_CANC.QTVENDIDA, C_VENDAS_CANC.VALORTOTAL, C_VENDAS_CANC.VRACRITVEND, C_VENDAS_CANC.VRDESITVEND, 0);

         /*IMPOSTO POR ITEM DA VENDA */
         V_NRSEQRELACIT := 0;

      END LOOP;
      /* FIM CLCULO VENDAS CANCELADAS PARA A FILIAL,LOJA E DATA */

/*      raise_application_error(-20501, 'Mensagem YY'||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

      /* DRF - CLCULO VENDAS CONCLUIDAS COM ITENS CANCELADOS - PARA A FILIAL,LOJA E DATA */
      V_DTLANCROP := '01/01/1990';
      FOR C_VENDAS_CANC IN(SELECT VE.CDFILIAL,VE.CDLOJA, VE.DTENTRVENDA,
                             SUM(TRUNC(IC.QTPRODVENDC * (IC.VRUNITVENDC + NVL(IC.VRUNITVENCLC,0)),2) + NVL(IC.VRACRITVENDC,0) - NVL(IC.VRDESITVENDC,0)) AS VALORTOTAL,
                             SUM(NVL(IC.VRACRITVENDC,0)) AS VRACRITVEND,
                             SUM(NVL(IC.VRDESITVENDC,0)) AS VRDESITVEND,
                             SUM(IC.QTPRODVENDC) AS QTVENDIDA
                        FROM  VENDA VE, ITVENDACAN IC, (SELECT DTDATA DIA
                                                          FROM DATA
                                                         WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE (VE.CDFILIAL    = P_CDFILIAL)
                          AND (VE.DTENTRVENDA = D.DIA)
                          AND (VE.CDFILIAL    = IC.CDFILIAL)
                          AND (VE.CDCAIXA     = IC.CDCAIXA)
                          AND (VE.NRSEQVENDA  = IC.NRSEQVENDA)
                        GROUP BY VE.CDFILIAL, VE.CDLOJA, VE.DTENTRVENDA) LOOP
         /*
         IF V_DTLANCROP <> C_VENDAS_CANC.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_VENDAS_CANC.DTENTRVENDA;

            V_DTLANCROP   := C_VENDAS_CANC.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;
         END IF;
         */

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_VENDAS_CANC.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_VENDAS_CANC.DTENTRVENDA;

            V_DTLANCROP   := C_VENDAS_CANC.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*INCLUI A VENDA NA TABELA LANCROPFILIAL - FILIAL,CAIXA,SEQVENDA, NRCUPOM E VALORES TOTAIS*/
         /*V_NRLANCROP := V_NRLANCROP + 1;*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP, VRIMPLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_VENDAS_CANC.DTENTRVENDA, 'C2', '',
             '',  '', '', C_VENDAS_CANC.CDFILIAL,'', V_CDFILCENTROP, '', '','','', C_VENDAS_CANC.CDLOJA,
             C_VENDAS_CANC.VRACRITVEND, C_VENDAS_CANC.VRDESITVEND, 0);

         /*INCLUI ITEM DO LANAMENTO*/
         V_NRITLANCROP := LPAD('00000' + 1,5,'0');

         /* INSERE UM REGISTRO COM TOTAIS DA VENDA, PRATICAMENTE REPETE OS VALORES DA LANCROPFILIAL. NO INSERE PRODUTO POR PRODUTO */
         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,  VRITEMLANCROP, VRACRITLANCROP, VRDESITLANCROP, VRIMPITLANCROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_VENDAS_CANC.CDFILIAL, '',
             '', '',  C_VENDAS_CANC.QTVENDIDA, C_VENDAS_CANC.VALORTOTAL, C_VENDAS_CANC.VRACRITVEND, C_VENDAS_CANC.VRDESITVEND, 0);

         /*IMPOSTO POR ITEM DA VENDA */
         V_NRSEQRELACIT := 0;

      END LOOP;
      /* FIM CLCULO VENDAS NO CANCELADAS COM ITENS CANCELADOS PARA A FILIAL,LOJA E DATA */

    /*  raise_application_error(-20501, 'Mensagem 10: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

      /* DRF - CLCULO DO CMV TOTAL POR SUB-GRUPOS DE PRODUTO DE VENDAS - SOMENTE PARA O FORSALE */
      V_DTLANCROP := '01/01/1990';
      FOR C_CONSUMO IN(SELECT V.CDFILIAL, V.DTENTRVENDA,P.CDGRUPPROD,P.CDSUBGRPROD,
                              SUM(I.QTPRODVEND) AS QTDETOTAL,
                              SUM(CUSTO_COMPOSICAO(I.CDPRODUTO,V.CDFILIAL,V.CDFILIAL,V_NRTIPOCUSTO,I.QTPRODVEND,'',V.DTENTRVENDA)) AS VALORTOTAL
                        FROM  VENDA V, ITEMVENDA I, PRSUBGRPROD P, (SELECT DTDATA DIA
                                                                      FROM DATA
                                                                     WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE (V.CDFILIAL    = P_CDFILIAL)
                          AND (V.DTENTRVENDA = D.DIA)
                          AND (V.CDFILIAL    = I.CDFILIAL)
                          AND (V.CDCAIXA     = I.CDCAIXA)
                          AND (V.NRSEQVENDA  = I.NRSEQVENDA)
                          AND (V.IDSITUVENDA = 'O')
                          AND (P.CDFILISUBGR(+) = V_CDFILISUBGR_VEN)
                          AND (P.CDGRUPPROD(+)  = V_CDGRUPPRODVEN)
                          AND (P.CDPRODUTO(+)   = I.CDPRODUTO)
                        GROUP BY V.CDFILIAL, V.DTENTRVENDA, P.CDGRUPPROD,P.CDSUBGRPROD) LOOP

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_CONSUMO.DTENTRVENDA THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_CONSUMO.DTENTRVENDA;

            V_DTLANCROP   := C_CONSUMO.DTENTRVENDA;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

            /* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*INCLUI LANAMENTO*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_CONSUMO.DTENTRVENDA, 'CM', '', '',
             '', '', '','', '', '', '','');

         /*INCLUI ITEM DO LANAMENTO*/
         V_NRITLANCROP := LPAD('00000' + 1,5,'0');

         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, '', '',
             '', '',  C_CONSUMO.QTDETOTAL, C_CONSUMO.VALORTOTAL,C_CONSUMO.CDGRUPPROD,C_CONSUMO.CDSUBGRPROD);

      END LOOP;
      /* FIM CLCULO DO CUSTO DA MERCADORIA POR SUB-GRUPO DE PRODUTOS VENDIDOS */

/*      raise_application_error(-20501, 'Mensagem 11: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

      /* DRF - GRAVACAO DOS PRODUTOS - POR QUANTIDADE, POR VALOR, RENTABILIDADE */
      V_DTLANCROP := '01/01/1990';
      FOR C_MESES IN(SELECT V.CDFILIAL,V.CDLOJA,V.DTENTRVENDA
                        FROM   VENDA V, ITEMVENDA I, (SELECT DTDATA DIA
                                                        FROM DATA
                                                       WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE (V.CDFILIAL    = P_CDFILIAL)
                          AND (V.DTENTRVENDA = D.DIA)
                          AND (V.CDFILIAL    = I.CDFILIAL)
                          AND (V.CDCAIXA     = I.CDCAIXA)
                          AND (V.NRSEQVENDA  = I.NRSEQVENDA)
                          AND (V.IDSITUVENDA = 'O')
                        GROUP BY V.CDFILIAL,V.CDLOJA,V.DTENTRVENDA
                        ORDER BY V.DTENTRVENDA) LOOP

         /* INICIO DO PROCESSO DOS PRODUTOS MAIS VENDIDOS POR ORDEM DE VALOR */
         V_DTLANCROP := TO_CHAR(C_MESES.DTENTRVENDA,'DD/MM/YYYY');   /*'01/'||SUBSTR(C_MESES.DATAREF,5,2)||'/'||SUBSTR(C_MESES.DATAREF,1,4);*/
         
		 V_NRROPFILIAL := NULL;
         SELECT MAX(NRROPFILIAL)
         INTO V_NRROPFILIAL
         FROM ROPFILIAL
         WHERE CDFILIAL    = P_CDFILIAL AND
               DTFILIALROP = V_DTLANCROP;

         IF V_NRROPFILIAL IS NULL THEN
            V_NRROPFILIAL := V_NRROPFILINI;
         END IF;

         /* PEGA O ULTIMO NUMERO DO LANAMENTO */
         SELECT MAX(NRLANCROP)
           INTO V_NRLANCROP
           FROM LANCROPFILIAL
          WHERE CDFILIAL = P_CDFILIAL AND
                NRROPFILIAL = V_NRROPFILIAL;

         IF V_NRLANCROP IS NULL THEN
            V_NRLANCROP  := 0;
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         ELSE
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         END IF;

         /* Inclui Lanamento - PRODUTO MAIOR VALOR */
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'PV', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_MESES.CDLOJA, 0,0);

         /* BUSCA OS PRODUTOS MAIS VENDIDOS POR VALOR PARA CADA MES - SERVE TAMBM PARA BUSCAR A QUANTIDADE VENDIDA POR SUBGRUPO PARA CALCULAR O GIRO */
         V_NRITLANCROP_AUX := 0;
         V_CONTADOR := 0;
         FOR C_PRODUTOS IN(SELECT V.CDFILIAL, I.CDPRODUTO,
                                  SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) AS VALORTOTAL,
                                  SUM(I.QTPRODVEND) AS QTDETOTAL,
                                  SUM(I.VRACRITVEND) AS VRACRITVEND,
                                  SUM(I.VRDESITVEND) AS VRDESITVEND
                           FROM   VENDA V, ITEMVENDA I
                           WHERE (V.CDFILIAL    = P_CDFILIAL)
                             AND (V.DTENTRVENDA = V_DTLANCROP)
                             AND (V.CDFILIAL    = I.CDFILIAL)
                             AND (V.CDCAIXA     = I.CDCAIXA)
                             AND (V.NRSEQVENDA  = I.NRSEQVENDA)
                             AND (V.IDSITUVENDA = 'O')
							 AND (V.CDLOJA      = C_MESES.CDLOJA)
                           GROUP BY V.CDFILIAL,I.CDPRODUTO
                           ORDER BY VALORTOTAL DESC) LOOP

            /*Inclui Item do Lanamento*/
            V_NRITLANCROP_AUX := V_NRITLANCROP_AUX + 1;

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_PRODUTOS.CDFILIAL, '',
                '', C_PRODUTOS.CDPRODUTO, C_PRODUTOS.QTDETOTAL, C_PRODUTOS.VALORTOTAL,'','', C_PRODUTOS.VRACRITVEND, C_PRODUTOS.VRDESITVEND);

            V_CONTADOR := V_CONTADOR + 1;

             IF V_CONTADOR = 10 THEN
               EXIT;
            END IF;
         END LOOP;
         /* FIM CLCULO DOS PRODUTOS MAIS VENDIDOS POR ORDEM DE VALOR */

         /* DRF - INCIO DOS PRODUTOS MAIS VENDIDOS POR ORDEM DE QUANTIDADE */
         V_DTLANCROP := TO_CHAR(C_MESES.DTENTRVENDA,'DD/MM/YYYY');   /*'01/'||SUBSTR(V_DATAREF,5,2)||'/'||SUBSTR(V_DATAREF,1,4);*/

         V_NRROPFILIAL := NULL;
         SELECT MAX(NRROPFILIAL)
         INTO V_NRROPFILIAL
         FROM ROPFILIAL
         WHERE CDFILIAL    = P_CDFILIAL AND
               DTFILIALROP = V_DTLANCROP;

         IF V_NRROPFILIAL IS NULL THEN
            V_NRROPFILIAL := V_NRROPFILINI;
         END IF;

     /* PEGA O ULTIMO NUMERO DO LANAMENTO */
         SELECT MAX(NRLANCROP)
           INTO V_NRLANCROP
           FROM LANCROPFILIAL
          WHERE CDFILIAL = P_CDFILIAL AND
                NRROPFILIAL = V_NRROPFILIAL;

         IF V_NRLANCROP IS NULL THEN
            V_NRLANCROP  := 0;
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         ELSE
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         END IF;

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'PQ', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_MESES.CDLOJA, 0,0);

         /* BUSCA OS PRODUTOS MAIS VENDIDOS POR QUANTIDADE PARA CADA MES - GRAVA APENAS OS 10 PRIMEIROS */
         V_NRITLANCROP_AUX := 0;
         V_CONTADOR := 0;
         FOR C_PRODUTOS IN(SELECT V.CDFILIAL, I.CDPRODUTO, I.CDGRUPPROD, I.CDSUBGRPROD,
                                  SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) AS VALORTOTAL,
                                  SUM(I.QTPRODVEND) AS QTDETOTAL,
                                  SUM(I.VRACRITVEND) AS VRACRITVEND,
                                  SUM(I.VRDESITVEND) AS VRDESITVEND
                            FROM VENDA V, ITEMVENDA I
                           WHERE (V.CDFILIAL    = P_CDFILIAL)
                             AND (V.DTENTRVENDA = V_DTLANCROP)
                             AND (V.CDFILIAL    = I.CDFILIAL)
                             AND (V.CDCAIXA     = I.CDCAIXA)
                             AND (V.NRSEQVENDA  = I.NRSEQVENDA)
                             AND (V.IDSITUVENDA = 'O')
							        AND (V.CDLOJA      = C_MESES.CDLOJA)
                           GROUP BY V.CDFILIAL,I.CDPRODUTO,I.CDGRUPPROD, I.CDSUBGRPROD
                           ORDER BY QTDETOTAL DESC) LOOP

            /*Inclui Item do Lanamento*/
            V_NRITLANCROP_AUX := V_NRITLANCROP_AUX + 1;

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_PRODUTOS.CDFILIAL, '',
                '', C_PRODUTOS.CDPRODUTO, C_PRODUTOS.QTDETOTAL, C_PRODUTOS.VALORTOTAL,C_PRODUTOS.CDGRUPPROD,C_PRODUTOS.CDSUBGRPROD,C_PRODUTOS.VRACRITVEND, C_PRODUTOS.VRDESITVEND);

            V_CONTADOR := V_CONTADOR + 1;

            IF V_CONTADOR = 10 THEN
               EXIT;
            END IF;
         END LOOP;
         /* FIM CLCULO DOS PRODUTOS MAIS VENDIDOS POR ORDEM DE QUANTIDADE */

         /* DRF - INCIO CLCULO RENTABILIDADE DOS PRODUTOS - PRODUTOS MAIS RENTAVEIS - GRAVA APENAS OS 10 PRIMEIROS */
         V_DTLANCROP := TO_CHAR(C_MESES.DTENTRVENDA,'DD/MM/YYYY');   /*'01/'||SUBSTR(V_DATAREF,5,2)||'/'||SUBSTR(V_DATAREF,1,4);*/

         V_NRROPFILIAL := NULL;
         SELECT MAX(NRROPFILIAL)
         INTO V_NRROPFILIAL
         FROM ROPFILIAL
         WHERE CDFILIAL    = P_CDFILIAL AND
               DTFILIALROP = V_DTLANCROP;

         IF V_NRROPFILIAL IS NULL THEN
            V_NRROPFILIAL := V_NRROPFILINI;
         END IF;

         /* PEGA O ULTIMO NUMERO DO LANAMENTO */
         SELECT MAX(NRLANCROP)
           INTO V_NRLANCROP
           FROM LANCROPFILIAL
          WHERE CDFILIAL = P_CDFILIAL AND
                NRROPFILIAL = V_NRROPFILIAL;

         IF V_NRLANCROP IS NULL THEN
            V_NRLANCROP  := 0;
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         ELSE
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         END IF;

/*      raise_application_error(-20501, 'Mensagem ANTES DO 16 1: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'RT', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_MESES.CDLOJA, 0,0);

         /* BUSCA OS PRODUTOS MAIS RENTAVEIS (PRECO TOTAL - IMPOSTO - CUSTO TOTAL) */
         V_NRITLANCROP_AUX := 0;
         V_CONTADOR := 0;
         FOR C_PRODUTOS IN(SELECT VE.CDFILIAL, IT.CDPRODUTO, IT.CDGRUPPROD, IT.CDSUBGRPROD,
                                  SUM(TRUNC(IT.QTPRODVEND * (IT.VRUNITVEND + NVL(IT.VRUNITVENDCL,0)),2) +
                                  NVL(IT.VRACRITVEND,0) - NVL(IT.VRDESITVEND,0)) - SUM(IP.VRIMPOPRODIT) -
                                  SUM(CUSTO_COMPOSICAO(IT.CDPRODUTO,VE.CDFILIAL,VE.CDFILIAL,V_NRTIPOCUSTO,IT.QTPRODVEND,'',VE.DTENTRVENDA)) AS VALORTOTAL,
                                  SUM(IT.QTPRODVEND ) AS QTDETOTAL,
                                  SUM(IT.VRACRITVEND) AS VRACRITVEND,
                                  SUM(IT.VRDESITVEND) AS VRDESITVEND
                           FROM   VENDA VE, ITEMVENDA IT, ITVENDAIMPOS IP
                           WHERE (VE.CDFILIAL    = P_CDFILIAL)
                             AND (VE.DTENTRVENDA = V_DTLANCROP)
                             AND (VE.CDFILIAL    = IT.CDFILIAL)
                             AND (VE.CDCAIXA     = IT.CDCAIXA)
                             AND (VE.NRSEQVENDA  = IT.NRSEQVENDA)
                             AND (VE.IDSITUVENDA = 'O')
                             AND (IT.CDFILIAL    = IP.CDFILIAL)
                             AND (IT.CDCAIXA     = IP.CDCAIXA )
                             AND (IT.NRSEQVENDA  = IP.NRSEQVENDA)
                             AND (IT.NRSEQUITVEND= IP.NRSEQUITVEND)
							 AND (VE.CDLOJA      = C_MESES.CDLOJA)
                           GROUP BY VE.CDFILIAL,IT.CDPRODUTO, IT.CDGRUPPROD, IT.CDSUBGRPROD
                           ORDER BY VALORTOTAL DESC) LOOP

            /*INCLUI ITEM DO LANAMENTO*/
            V_NRITLANCROP_AUX := V_NRITLANCROP_AUX + 1;

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_PRODUTOS.CDFILIAL, '',
                '', C_PRODUTOS.CDPRODUTO, C_PRODUTOS.QTDETOTAL, C_PRODUTOS.VALORTOTAL,C_PRODUTOS.CDGRUPPROD,C_PRODUTOS.CDSUBGRPROD, C_PRODUTOS.VRACRITVEND, C_PRODUTOS.VRDESITVEND);

            V_CONTADOR := V_CONTADOR + 1;

            IF V_CONTADOR = 10 THEN
               EXIT;
            END IF;
         END LOOP;
         /* FIM CLCULO RENTABILIDADE DOS PRODUTOS - PRODUTOS MAIS RENTAVEIS */

/* DRF - INCIO CLCULO RENTABILIDADE DOS PRODUTOS - PRODUTOS MENOS RENTAVEIS - GRAVA APENAS OS 10 PRIMEIROS */

         V_DTLANCROP := TO_CHAR(C_MESES.DTENTRVENDA,'DD/MM/YYYY');   /*'01/'||SUBSTR(V_DATAREF,5,2)||'/'||SUBSTR(V_DATAREF,1,4);*/

         V_NRROPFILIAL := NULL;
         SELECT MAX(NRROPFILIAL)
         INTO V_NRROPFILIAL
         FROM ROPFILIAL
         WHERE CDFILIAL    = P_CDFILIAL AND
               DTFILIALROP = V_DTLANCROP;

         IF V_NRROPFILIAL IS NULL THEN
            V_NRROPFILIAL := V_NRROPFILINI;
         END IF;

  /* PEGA O ULTIMO NUMERO DO LANAMENTO */
         SELECT MAX(NRLANCROP)
           INTO V_NRLANCROP
           FROM LANCROPFILIAL
          WHERE CDFILIAL = P_CDFILIAL AND
                NRROPFILIAL = V_NRROPFILIAL;

         IF V_NRLANCROP IS NULL THEN
            V_NRLANCROP  := 0;
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         ELSE
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         END IF;

/*      raise_application_error(-20501, 'Mensagem ANTES DO 16 1: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'MR', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_MESES.CDLOJA, 0,0);

         /* BUSCA OS PRODUTOS MENOS RENTAVEIS (PRECO TOTAL - IMPOSTO - CUSTO TOTAL) */
         V_NRITLANCROP_AUX := 0;
         V_CONTADOR := 0;
         FOR C_PRODUTOS IN(SELECT VE.CDFILIAL, IT.CDPRODUTO, IT.CDGRUPPROD, IT.CDSUBGRPROD,
                                  SUM(TRUNC(IT.QTPRODVEND * (IT.VRUNITVEND + NVL(IT.VRUNITVENDCL,0)),2) +
                                  NVL(IT.VRACRITVEND,0) - NVL(IT.VRDESITVEND,0)) - SUM(IP.VRIMPOPRODIT) -
                                  SUM(CUSTO_COMPOSICAO(IT.CDPRODUTO,VE.CDFILIAL,VE.CDFILIAL,V_NRTIPOCUSTO,IT.QTPRODVEND,'',VE.DTENTRVENDA)) AS VALORTOTAL,
                                  SUM(IT.QTPRODVEND ) AS QTDETOTAL,
                                  SUM(IT.VRACRITVEND) AS VRACRITVEND,
                                  SUM(IT.VRDESITVEND) AS VRDESITVEND
                           FROM   VENDA VE, ITEMVENDA IT, ITVENDAIMPOS IP
                           WHERE (VE.CDFILIAL    = P_CDFILIAL)
                             AND (VE.DTENTRVENDA = V_DTLANCROP)
                             AND (VE.CDFILIAL    = IT.CDFILIAL)
                             AND (VE.CDCAIXA     = IT.CDCAIXA)
                             AND (VE.NRSEQVENDA  = IT.NRSEQVENDA)
                             AND (VE.IDSITUVENDA = 'O')
                             AND (IT.CDFILIAL    = IP.CDFILIAL)
                             AND (IT.CDCAIXA     = IP.CDCAIXA )
                             AND (IT.NRSEQVENDA  = IP.NRSEQVENDA)
                             AND (IT.NRSEQUITVEND= IP.NRSEQUITVEND)
							 AND (VE.CDLOJA      = C_MESES.CDLOJA)
                           GROUP BY VE.CDFILIAL,IT.CDPRODUTO, IT.CDGRUPPROD, IT.CDSUBGRPROD
                           ORDER BY VALORTOTAL ASC) LOOP

            /*INCLUI ITEM DO LANAMENTO*/
            V_NRITLANCROP_AUX := V_NRITLANCROP_AUX + 1;

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_PRODUTOS.CDFILIAL, '',
                '', C_PRODUTOS.CDPRODUTO, C_PRODUTOS.QTDETOTAL, C_PRODUTOS.VALORTOTAL,C_PRODUTOS.CDGRUPPROD,C_PRODUTOS.CDSUBGRPROD, C_PRODUTOS.VRACRITVEND, C_PRODUTOS.VRDESITVEND);

            V_CONTADOR := V_CONTADOR + 1;

            IF V_CONTADOR = 10 THEN
               EXIT;
            END IF;
         END LOOP;
         /* FIM CLCULO RENTABILIDADE DOS PRODUTOS - PRODUTOS MENOS RENTAVEIS */         


/*      raise_application_error(-20501, 'Mensagem 15: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

         /* DRF - INCIO DOS PRODUTOS MENOS VENDIDOS POR ORDEM DE QUANTIDADE */
         V_DTLANCROP := TO_CHAR(C_MESES.DTENTRVENDA,'DD/MM/YYYY');   /*'01/'||SUBSTR(V_DATAREF,5,2)||'/'||SUBSTR(V_DATAREF,1,4);*/

         V_NRROPFILIAL := NULL;
         SELECT MAX(NRROPFILIAL)
         INTO V_NRROPFILIAL
         FROM ROPFILIAL
         WHERE CDFILIAL    = P_CDFILIAL AND
               DTFILIALROP = V_DTLANCROP;

         IF V_NRROPFILIAL IS NULL THEN
            V_NRROPFILIAL := V_NRROPFILINI;
         END IF;

         /* PEGA O ULTIMO NUMERO DO LANAMENTO */
         SELECT MAX(NRLANCROP)
           INTO V_NRLANCROP
           FROM LANCROPFILIAL
          WHERE CDFILIAL = P_CDFILIAL AND
                NRROPFILIAL = V_NRROPFILIAL;

         IF V_NRLANCROP IS NULL THEN
            V_NRLANCROP  := 0;
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         ELSE
            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         END IF;

/*      raise_application_error(-20501, 'Mensagem ANTES DO 16: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'M1', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_MESES.CDLOJA, 0,0);

         /* BUSCA OS PRODUTOS MENOS VENDIDOS POR QUANTIDADE PARA CADA MES - GRAVA APENAS OS 10 PRIMEIROS */
         V_NRITLANCROP_AUX := 0;
         V_CONTADOR := 0;
         FOR C_PRODUTOS IN(SELECT V.CDFILIAL, I.CDPRODUTO, I.CDGRUPPROD, I.CDSUBGRPROD,
                                  SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) AS VALORTOTAL,
                                  SUM(I.QTPRODVEND) AS QTDETOTAL,
                                  SUM(I.VRACRITVEND) AS VRACRITVEND,
                                  SUM(I.VRDESITVEND) AS VRDESITVEND
                           FROM   VENDA V, ITEMVENDA I
                           WHERE (V.CDFILIAL    = P_CDFILIAL)
                             AND (V.DTENTRVENDA = V_DTLANCROP)
                             AND (V.CDFILIAL    = I.CDFILIAL)
                             AND (V.CDCAIXA     = I.CDCAIXA)
                             AND (V.NRSEQVENDA  = I.NRSEQVENDA)
                             AND (V.IDSITUVENDA = 'O')
							 AND (V.CDLOJA      = C_MESES.CDLOJA)
                           GROUP BY V.CDFILIAL,I.CDPRODUTO,I.CDGRUPPROD, I.CDSUBGRPROD
                           ORDER BY QTDETOTAL ASC) LOOP

            /*Inclui Item do Lanamento*/
            V_NRITLANCROP_AUX := V_NRITLANCROP_AUX + 1;

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_PRODUTOS.CDFILIAL, '',
                '', C_PRODUTOS.CDPRODUTO, C_PRODUTOS.QTDETOTAL, C_PRODUTOS.VALORTOTAL,C_PRODUTOS.CDGRUPPROD,C_PRODUTOS.CDSUBGRPROD,C_PRODUTOS.VRACRITVEND, C_PRODUTOS.VRDESITVEND);

            V_CONTADOR := V_CONTADOR + 1;

            IF V_CONTADOR = 10 THEN
               EXIT;
            END IF;
         END LOOP;
         /* FIM CLCULO DOS PRODUTOS MENOS VENDIDOS POR ORDEM DE QUANTIDADE */

      END LOOP;

/*      raise_application_error(-20501, 'Mensagem 16: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

      /* DRF - GRAVA O VALOR TOTAL DE SANGRIAS DIA POR DIA */
      V_DTLANCROP := '01/01/1990';
      FOR C_SANGRIA IN(SELECT M.CDFILIAL,C.CDLOJA,M.DTMOVIMCAIXA AS DATAREF,
                              SUM(VRMOVIVEND) AS VALOR_SANGRIA
                        FROM   MOVCAIXA M, CAIXA C, (SELECT DTDATA DIA
                                                       FROM DATA
                                                      WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE (M.CDFILIAL    = P_CDFILIAL)
                          AND (M.DTMOVIMCAIXA = D.DIA)
                          AND (M.IDTIPOMOVIVE = 'G')
                          AND (M.CDFILIAL = C.CDFILIAL)
                          AND (M.CDCAIXA  = C.CDCAIXA)
                        GROUP BY M.CDFILIAL,C.CDLOJA,M.DTMOVIMCAIXA
                        ORDER BY M.DTMOVIMCAIXA) LOOP


         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_SANGRIA.DATAREF THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_SANGRIA.DATAREF;

            V_DTLANCROP   := C_SANGRIA.DATAREF;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;


         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'SG', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_SANGRIA.CDLOJA, 0,0);

         /*Inclui Item do Lanamento*/
         V_NRITLANCROP_AUX := '00001';

         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_SANGRIA.CDFILIAL, '',
             '', '', 1, C_SANGRIA.VALOR_SANGRIA,'','', 0, 0);

      END LOOP;
      /* FIM CLCULO DO VALOR TOTAL DE SANGRIAS */

      /* DRF - GRAVA O VALOR TOTAL DOS CONTRA VALES EMITIDOS DIA A DIA */
      V_DTLANCROP := '01/01/1990';
      FOR C_SANGRIA IN(SELECT M.CDFILIAL,C.CDLOJA,M.DTMOVIMCAIXA AS DATAREF,
                              SUM(VRMOVIVEND) AS VALOR_SANGRIA
                        FROM   MOVCAIXA M, CAIXA C, TIPORECE T, (SELECT DTDATA DIA
                                                                   FROM DATA
                                                                  WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE (M.CDFILIAL    = P_CDFILIAL)
                          AND (M.DTMOVIMCAIXA = D.DIA)
                          AND (M.IDTIPOMOVIVE = 'S')
                          AND (M.CDTIPORECE = T.CDTIPORECE)
                          AND (T.IDTIPORECE = '7')
                          AND (M.CDFILIAL = C.CDFILIAL)
                          AND (M.CDCAIXA  = C.CDCAIXA)
                        GROUP BY M.CDFILIAL,C.CDLOJA,M.DTMOVIMCAIXA
                        ORDER BY M.DTMOVIMCAIXA) LOOP


         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_SANGRIA.DATAREF THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_SANGRIA.DATAREF;

            V_DTLANCROP   := C_SANGRIA.DATAREF;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'S1', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_SANGRIA.CDLOJA, 0,0);

         /*Inclui Item do Lanamento*/
         V_NRITLANCROP_AUX := '00001';

         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_SANGRIA.CDFILIAL, '',
             '', '', 1, C_SANGRIA.VALOR_SANGRIA,'','', 0, 0);

      END LOOP;
      /* FIM CLCULO DO VALOR TOTAL DOS CONTRA VALES EMITIDOS */

/*      raise_application_error(-20501, 'Mensagem 18: '||V_DTINIC||' - '||V_NRROPFILIAL||' - '||V_NRROPFILINI||'LANCROP :'||LPAD(V_NRLANCROP,10,'0'), True); */

      /* DRF - GRAVA O VALOR TOTAL DOS SUPRIMENTOS DIA A DIA */
      V_DTLANCROP := '01/01/1990';
      FOR C_SANGRIA IN(SELECT M.CDFILIAL,C.CDLOJA,M.DTMOVIMCAIXA AS DATAREF,
                              SUM(VRMOVIVEND) AS VALOR_SANGRIA
                        FROM   MOVCAIXA M, CAIXA C, (SELECT DTDATA DIA
                                                       FROM DATA
                                                      WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE (M.CDFILIAL    = P_CDFILIAL)
                          AND (M.DTMOVIMCAIXA = D.DIA)
                          AND (M.IDTIPOMOVIVE = 'U')
                          AND (M.CDFILIAL = C.CDFILIAL)
                          AND (M.CDCAIXA  = C.CDCAIXA)
                        GROUP BY M.CDFILIAL,C.CDLOJA,M.DTMOVIMCAIXA
                        ORDER BY M.DTMOVIMCAIXA) LOOP

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_SANGRIA.DATAREF THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_SANGRIA.DATAREF;

            V_DTLANCROP   := C_SANGRIA.DATAREF;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, CDCAIXA, CDLOJA, VRACRLANCROP, VRDESLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_DTLANCROP, 'S2', '',
             '',  '', '', P_CDFILIAL, '', V_CDFILCENTROP, '', '', '','',C_SANGRIA.CDLOJA, 0,0);

         /*Inclui Item do Lanamento*/
         V_NRITLANCROP_AUX := '00001';

         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,VRITEMLANCROP,CDGRUPPRODROP,CDSUBGRPRODROP, VRACRITLANCROP, VRDESITLANCROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), LPAD(V_NRITLANCROP_AUX,5,'0'), C_SANGRIA.CDFILIAL, '',
             '', '', 1, C_SANGRIA.VALOR_SANGRIA,'','', 0, 0);

      END LOOP;
      /* FIM CLCULO DO VALOR TOTAL DOS SUPRIMENTOS */

   END IF;

   /* DRF - Clculo do Consumo - Consumo Compra - S MUDA O GRUPO DE PRODUTOS PARAMETRIZADO */
   IF (V_IDCOMPRAROP = 'S') AND (V_IDTPAPURACAO <> '1') THEN
      V_DTLANCROP := '01/01/1990';
      FOR C_CONSCOMPRA IN (SELECT N.CDTIPOOPER, N.NRNOTAFISC, N.CDFILIAL, CDFILIRECE,
                                  N.NRLANCTONF, DTENTRSAID,   N.CDSERIE, N.CDFORNECED,
                                  N.IDSTATUS,   N.DTINIREFEFAT, N.DTFINREFEFAT, P.NUMERORE,
                                  L.NRLANCESTQ, N.NRSEQCAPADOC
                             FROM NOTAFISCAL N, LANCTOESTOQ L,
                                 (SELECT NRNUMERNF AS NUMERORE, CDFILIAL, DTNUMERNF AS DATARE
                                    FROM NUMERORNF, (SELECT DTDATA DIA
                                                       FROM DATA
                                                      WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                                   WHERE CDFILIAL = P_CDFILIAL
                                     AND IDENTRSAID = 'E'
                                     AND DTNUMERNF = D.DIA) P,
                                  (SELECT DTDATA DIA
                                     FROM DATA
                                    WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                            WHERE (N.CDFILIRECE    = P_CDFILIAL)
                              AND (N.IDENTRSAIDOP  = 'E')
                              AND (N.DTENTRSAID = D.DIA)
                              AND (N.CDFILIAL      = L.CDFILIAL)
                              AND (N.NRLANCTONF    = L.NRLANCTONF)
                              AND (N.CDFILIAL      = P.CDFILIAL(+))
                              AND (N.DTENTRSAID    = P.DATARE(+))
							  AND (N.NRSEQCAPADOC  = P.NUMERORE(+))
                              AND (N.IDSTATUS    <> 'C')
                              AND (N.IDSISTEMA NOT IN ('PAG','REC','FIS','CMP') OR N.IDSISTEMA IS NULL)
                            UNION ALL
                           SELECT '' AS CDTIPOOPER, '' AS NRNOTAFISC, L.CDFILIAL, L.CDFILIMOVI AS CDFILIRECE,
                                  '' AS NRLANCTONF, L.DTLANCESTQ AS DTENTRSAID, '' AS CDSERIE, '' AS CDFORNECED,
                                  '' AS IDSTATUS, SYSDATE AS DTINIREFEFAT, SYSDATE AS DTFINREFEFAT, '' AS NUMERORE,
                                  L.NRLANCESTQ, '' AS NRSEQCAPADOC
                             FROM LANCTOESTOQ L, (SELECT DTDATA DIA
                                                    FROM DATA
                                                   WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                            WHERE (L.CDFILIMOVI = P_CDFILIAL)
                              AND (L.IDTPLANCTO = '2'       )
                              AND (L.IDENTRSAIDOP IS NULL   )
                              AND (L.CDTIPOOPER IS NULL     )
                              AND (L.DTLANCESTQ = D.DIA)
                           ORDER BY DTENTRSAID) LOOP

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_CONSCOMPRA.DTENTRSAID THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_CONSCOMPRA.DTENTRSAID;

            V_DTLANCROP   := C_CONSCOMPRA.DTENTRSAID;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, NUMEROREROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_CONSCOMPRA.DTENTRSAID, 'CO', C_CONSCOMPRA.CDFORNECED,
             C_CONSCOMPRA.CDTIPOOPER,   C_CONSCOMPRA.NRNOTAFISC, C_CONSCOMPRA.CDSERIE, C_CONSCOMPRA.CDFILIAL,
             C_CONSCOMPRA.NRLANCTONF,   V_CDFILCENTROP, C_CONSCOMPRA.IDSTATUS, C_CONSCOMPRA.DTINIREFEFAT,
             C_CONSCOMPRA.DTFINREFEFAT, C_CONSCOMPRA.NUMERORE);

         V_NRITLANCROP   := '00000';
         V_NRSEQRELACIT  := 0;
         V_PRODUTO       := '';
         V_NRSEQIT       := 'N';
         V_PRIIMP        := 0;
         FOR C_ITCONSCOMPRA IN(/*SELECT AN.CDSUBGRPROD, AN.CDGRUPPROD, SUM(I.VRBRUTITEM) AS VALORTOTAL, SUM(I.QTITEMPROD) AS QUANTIDADE
                                 FROM ITEMPRODUTO I, SUBGRUPPROD SG, PARFILIALROP P, PRSUBGRPROD AN, PRODFILI PR
                                WHERE (I.CDFILIAL      = C_CONSCOMPRA.CDFILIAL  ) AND
                                      (I.NRLANCTONF    = C_CONSCOMPRA.NRLANCTONF) AND
                                      (P.CDFILIAL      = V_FILIALPAR            ) AND
									  (P.CDGRUPPRODDRL = SG.CDGRUPPROD          ) AND
									  (AN.CDFILISUBGR  = V_CDFILISUBGR_DRL      ) AND
                                      (AN.CDSUBGRPROD  = SG.CDSUBGRPROD         ) AND
                                      (AN.CDGRUPPROD   = SG.CDGRUPPROD          ) AND
									  (AN.CDPRODUTO    = I.CDPRODUTO            ) AND
                                      (PR.CDFILIAL     = P_CDFILIAL             ) AND
                                      (PR.CDPRODUTO    = I.CDPRODUTO            ) AND
									  (NVL(PR.IDCNTRESTOQ, 'S') = 'S'           )
                                  GROUP BY AN.CDSUBGRPROD, AN.CDGRUPPROD
                                  ORDER BY AN.CDSUBGRPROD, AN.CDGRUPPROD*/
							  SELECT AN.CDSUBGRPROD,   
                                     AN.CDGRUPPROD,   
                                     SUM(I.QTLANCTOEST*I.VRLANCTOEST) AS VRLANCTOEST,
                                     SUM(I.QTLANCTOEST*I.VRLANCTOBRUT) AS VRLANCTOBRUT,
                                     SUM(NVL(CUSTO_PRODUTO_LCEST(I.CDFILIMOVI, I.CDPRODMOVI, V_NRTIPOCUSTO, I.DTLANCMOVI, SYSDATE, I.CDALMOXARIFE, I.CDLOCALESTOQ,  I.NRLOTEESTQ, I.NRSUBLOTE),0) * I.QTLANCTOEST) AS VRCUSTO,									 
                                     SUM(I.QTLANCTOEST) AS QUANTIDADE                                   
                                FROM ITLANCTOEST I,   
                                     SUBGRPRODFIL SG, 
                                     PRODFILI PR,   
                                     PRODUTO H,  

                                    ( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD )AN   

                                WHERE (I.CDFILIAL      = C_CONSCOMPRA.CDFILIAL  )    AND   
                                      (I.NRLANCESTQ    = C_CONSCOMPRA.NRLANCESTQ)    AND   
                                      (SG.CDFILISUBGR  = V_CDFILISUBGR_DRL      )    AND   
                                      (SG.CDGRUPPROD   = V_CDGRUPPRODDRL        )    AND   
                                      (SG.CDFILISUBGR  = AN.CDFILISUBGR         )    AND   
                                      (SG.CDSUBGRPROD  = AN.CDSUBGRPROD         )    AND   
                                      (SG.CDGRUPPROD   = AN.CDGRUPPROD          )    AND   
                                      (I.CDPRODUTO     = AN.CDPRODUTO           )    AND   
                                      (H.CDPRODUTO     = I.CDPRODUTO            )    AND   
                                      (PR.CDFILIAL     = P_CDFILIAL             )    AND   
                                      (PR.CDPRODUTO    = H.CDPRODESTO           )    AND    
                                      (NVL(PR.IDCNTRESTOQ,'S')  = 'S'           )
                                GROUP BY AN.CDSUBGRPROD, AN.CDGRUPPROD
								ORDER BY AN.CDSUBGRPROD, AN.CDGRUPPROD) LOOP

               IF (NVL(V_PRODUTO,'N') <> C_ITCONSCOMPRA.CDSUBGRPROD)THEN

                  BEGIN

                     SELECT SUM(VRCUSTLOGLAN) VRCUSTLOGLAN, SUM(VRSEGULOGLAN) VRSEGULOGLAN
                            INTO V_VRCUSTLOGLAN, V_VRSEGULOGLAN
                       FROM SUBGRUPPROD SG, PARFILIALROP P, PRSUBGRPROD AN, LANCTOESTOQ L, ITLANCTOEST IT, PRODFILI PR
                       WHERE
                          (IT.CDFILIAL     = C_CONSCOMPRA.CDFILIAL     ) AND
                          (IT.NRLANCESTQ   = C_CONSCOMPRA.NRLANCESTQ   ) AND
                          (P.CDFILIAL      = V_FILIALPAR               ) AND
						  (P.CDGRUPPRODDRL = SG.CDGRUPPROD             ) AND
                          (AN.CDFILISUBGR  = V_CDFILISUBGR_DRL         ) AND
                          (AN.CDSUBGRPROD  = C_ITCONSCOMPRA.CDSUBGRPROD) AND
                          (AN.CDSUBGRPROD  = SG.CDSUBGRPROD            ) AND
                          (AN.CDGRUPPROD   = SG.CDGRUPPROD             ) AND
						  (AN.CDPRODUTO    = IT.CDPRODUTO              ) AND
                          (L.NRLANCTONF(+) = C_CONSCOMPRA.NRLANCTONF   ) AND
                          (L.CDFILIAL  (+) = IT.CDFILIAL               ) AND
                          (L.NRLANCESTQ(+) = IT.NRLANCESTQ             ) AND
                          (PR.CDFILIAL     = P_CDFILIAL                ) AND
                          (PR.CDPRODUTO    = IT.CDPRODMOVI             ) AND
						  (NVL(PR.IDCNTRESTOQ, 'S') = 'S'              ) AND
						  (NVL(IT.IDEVOLESTOQ, 'S') = 'S'              );
                  EXCEPTION
                     WHEN NO_DATA_FOUND THEN BEGIN
                        V_VRCUSTLOGLAN   := 0;
                        V_VRSEGULOGLAN   := 0;
                     END;
                  END;
				  
				  /* Validao do Relatrio Movimentao de Estoque */
				  IF (V_NRTIPOCUSTO <> 3) and (V_NRTIPOCUSTO <> 4) AND (V_NRTIPOCUSTO <> 42) and (V_NRTIPOCUSTO <> 43) THEN
				     V_VALORTOTAL := C_ITCONSCOMPRA.VRCUSTO;
				  ELSE
				     IF (V_NRTIPOCUSTO <> 4) and (V_NRTIPOCUSTO <> 43) THEN
                        V_VALORTOTAL := C_ITCONSCOMPRA.VRLANCTOEST;
                     ELSIF (V_NRTIPOCUSTO = 4) or (V_NRTIPOCUSTO = 43) THEN
                        V_VALORTOTAL := C_ITCONSCOMPRA.VRLANCTOBRUT;
                     END IF;
				  END IF;

                  /*Inclui Item do Lanamento*/
                  V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');
                  V_PRODUTO     := C_ITCONSCOMPRA.CDSUBGRPROD;

                  INSERT INTO ITLANCROPFILIAL
                     (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                      NRSEQITPRODROP, CDITEMLANCROP  ,QTITEMLANCROP, VRITEMLANCROP,
                      CDGRUPPRODROP, CDSUBGRPRODROP, VRCUSTOLOGITROP, VRCUSTSEGPROD)
                  VALUES
                    (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_CONSCOMPRA.CDFILIAL, C_CONSCOMPRA.NRLANCTONF,
                     '', C_ITCONSCOMPRA.CDSUBGRPROD, C_ITCONSCOMPRA.QUANTIDADE, V_VALORTOTAL,
                     C_ITCONSCOMPRA.CDGRUPPROD, C_ITCONSCOMPRA.CDSUBGRPROD, V_VRCUSTLOGLAN,V_VRSEGULOGLAN );

                  V_CONSUMO := V_CONSUMO + V_VALORTOTAL;
               END IF;
            IF V_PRIIMP = 0 THEN
               FOR C_IMPOSTOCC IN
                  (SELECT R.CDIMPOSTO, SUM(VRIMPOSTOIT) AS VALORIMPOSTO
                     FROM IMPOSTOROP R, ITEMPROIMPOS T, ITEMPRODUTO I
                    WHERE (I.CDFILIAL     = C_CONSCOMPRA.CDFILIAL)
                      AND (I.NRLANCTONF   = C_CONSCOMPRA.NRLANCTONF)
                      AND (I.CDFILIAL     = T.CDFILIAL)
                      AND (I.NRLANCTONF   = T.NRLANCTONF)
                      AND (I.NRSEQITPROD  = T.NRSEQITPROD)
                      AND (T.NRITPROIMPOS = '1')
                      AND (T.CDIMPOSTO    = R.CDIMPOSTO)
                      AND (R.CDFILIAL     = V_FILIALPAR)
                      AND (R.IDTPIMPOSTOROP = 'CC')
                    GROUP BY R.CDIMPOSTO) LOOP

                    V_NRSEQRELACIT := V_NRSEQRELACIT + 1;

                  INSERT INTO ITRELACITROP
                     (CDFILIAL,  NRROPFILIAL, NRLANCROP, NRITLANCROP, NRSEQRELACITROP,
                      CDITRELITROP, QTITRELITROP, VRITRELITROP)
                  VALUES
                     (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, V_NRSEQRELACIT,
                      C_IMPOSTOCC.CDIMPOSTO, 0, C_IMPOSTOCC.VALORIMPOSTO);

                  V_PRIIMP := 1;
               END LOOP;
            END IF;

         END LOOP;

      END LOOP;
   END IF;
   /* FIM DO CALCULO DAS ENTRADAS COM NOTA FISCAL PARA O DRL */

   /* DRF - Consumo Sadas - FORSALE */
   IF (V_IDNFSAIDAROP = 'S') AND (V_IDTPAPURACAO <> '1') THEN
      /* Saidas com Nota Fiscal - No pega as sadas originadas de consolidao */
      V_DTLANCROP := '01/01/1990';
      FOR C_CONSSAIDA IN (SELECT N.CDCLIENTE,  N.CDTIPOOPER, N.NRNOTAFISC, N.CDFILIAL,
                                 N.NRLANCTONF, DTENTRSAID,   N.CDSERIE, N.CDFORNECED,
                                 N.IDSTATUS,   N.DTINIREFEFAT, N.DTFINREFEFAT, P.NUMERORE
                            FROM NOTAFISCAL N, LANCTOESTOQ L,
                                 (SELECT NRNUMERNF AS NUMERORE, CDFILIAL, DTNUMERNF AS DATARE
                                    FROM NUMERORNF, (SELECT DTDATA DIA
                                                       FROM DATA
                                                      WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                                   WHERE CDFILIAL = P_CDFILIAL
                                     AND IDENTRSAID = 'S'
                                     AND DTNUMERNF = D.DIA) P,
                                 (SELECT DTDATA DIA
                                    FROM DATA
                                   WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                          WHERE (N.CDFILIEMIT   = P_CDFILIAL)
                            AND (N.IDENTRSAIDOP = 'S')
                            AND (N.DTENTRSAID = D.DIA)
                            AND (N.CDFILIAL   = L.CDFILIAL)
                            AND (N.NRLANCTONF = L.NRLANCTONF)
                            AND (N.CDFILIAL   = P.CDFILIAL(+))
                            AND (N.DTENTRSAID = P.DATARE(+))
                            AND (N.IDSTATUS    <> 'C')
                            AND (N.IDSISTEMA NOT IN ('PAG','REC','FIS','CMP','VND','PDV')  OR N.IDSISTEMA IS NULL))LOOP

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_CONSSAIDA.DTENTRSAID THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_CONSSAIDA.DTENTRSAID;

            V_DTLANCROP   := C_CONSSAIDA.DTENTRSAID;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, NUMEROREROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_CONSSAIDA.DTENTRSAID, 'SC', C_CONSSAIDA.CDFORNECED,
             C_CONSSAIDA.CDTIPOOPER,  C_CONSSAIDA.NRNOTAFISC, C_CONSSAIDA.CDSERIE, C_CONSSAIDA.CDFILIAL,
             C_CONSSAIDA.NRLANCTONF, V_CDFILCENTROP, C_CONSSAIDA.IDSTATUS, C_CONSSAIDA.DTINIREFEFAT,
             C_CONSSAIDA.DTFINREFEFAT, C_CONSSAIDA.NUMERORE);

         V_NRITLANCROP  := '00000';
         V_NRSEQRELACIT := 0;
         V_PRODUTO      := 'N';
         V_NRSEQIT      := 'N';


         SELECT MAX(CDFILIALIT), MAX(NRLANCTONFIT)
         INTO V_CDFILIALIT, V_NRLANCTONFIT
         FROM ITEMNOTAFISC
         WHERE CDFILIAL = C_CONSSAIDA.CDFILIAL
         AND NRLANCTONF = C_CONSSAIDA.NRLANCTONF;

         V_PRIIMP := 0;
         FOR C_ITCONSSAIDA IN(SELECT AN.CDSUBGRPROD, AN.CDGRUPPROD,SUM(I.VRTOTLANCTO) AS VALORTOTAL,SUM(I.QTLANCTOEST) AS QUANTIDADE
                              FROM   ITLANCTOEST I, GRUPPROD GR,SUBGRUPPROD SG, PARFILIALROP P,
							         
									 ( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD ) AN, LANCTOESTOQ L
                              
							  WHERE (I.CDFILIAL     = L.CDFILIAL)                 AND
                                    (I.NRLANCESTQ   = L.NRLANCESTQ)               AND
                                    (P.CDFILIAL     = V_FILIALPAR)                AND
                                    (CDFILISUBGR    = V_CDFILISUBGR_DRL)          AND
                                    (P.CDGRUPPRODDRL= GR.CDGRUPPROD)              AND
                                    (GR.CDGRUPPROD  = SG.CDGRUPPROD)              AND
                                    (SG.CDSUBGRPROD = AN.CDSUBGRPROD)             AND
                                    (I.CDPRODMOVI   = AN.CDPRODUTO)               AND
                                    (SG.CDGRUPPROD  = AN.CDGRUPPROD)              AND
                                    (L.CDFILIAL     = C_CONSSAIDA.CDFILIAL)       AND
                                    (L.NRLANCTONF   = C_CONSSAIDA.NRLANCTONF)     AND
                                    (I.CDPRODMOVI   = (SELECT DISTINCT IT.CDPRODMOVI
                                                       FROM ITLANCTOEST IT
                                                      WHERE L.CDFILIAL   = IT.CDFILIAL
                                                        AND L.NRLANCESTQ = IT.NRLANCESTQ
                                                        AND I.CDPRODMOVI = IT.CDPRODMOVI
                                                        AND NVL(IDEVOLESTOQ, 'S') = 'S'))
                              GROUP BY AN.CDSUBGRPROD, AN.CDGRUPPROD
                              ORDER BY AN.CDSUBGRPROD, AN.CDGRUPPROD)LOOP

            IF (NVL(V_PRODUTO,'N') <> C_ITCONSSAIDA.CDSUBGRPROD)THEN

               /*Inclui Item do Lanamento*/
               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');
               V_PRODUTO := C_ITCONSSAIDA.CDSUBGRPROD;

               INSERT INTO ITLANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                   NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP, VRITEMLANCROP,
                   CDGRUPPRODROP, CDSUBGRPRODROP)
               VALUES
                  (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_CONSSAIDA.CDFILIAL, C_CONSSAIDA.NRLANCTONF,
                   '', C_ITCONSSAIDA.CDSUBGRPROD,  C_ITCONSSAIDA.QUANTIDADE, C_ITCONSSAIDA.VALORTOTAL,
                   C_ITCONSSAIDA.CDGRUPPROD, C_ITCONSSAIDA.CDSUBGRPROD);

               V_CONSUMO := V_CONSUMO - C_ITCONSSAIDA.VALORTOTAL;

            END IF;

            IF V_PRIIMP = 0 THEN
               FOR C_IMPOSTOCS IN
                  (SELECT R.CDIMPOSTO, SUM(VRIMPOSTOIT) AS VALORIMPOSTO
                     FROM IMPOSTOROP R, ITEMPROIMPOS T, ITEMPRODUTO I
                    WHERE (I.CDFILIAL     = C_CONSSAIDA.CDFILIAL)
                      AND (I.NRLANCTONF   = C_CONSSAIDA.NRLANCTONF)
                      AND (I.CDFILIAL     = T.CDFILIAL)
                      AND (I.NRLANCTONF   = T.NRLANCTONF)
                      AND (I.NRSEQITPROD  = T.NRSEQITPROD)
                      AND (T.NRITPROIMPOS = '1')
                      AND (T.CDIMPOSTO    = R.CDIMPOSTO)
                      AND (R.CDFILIAL     = V_FILIALPAR)
                      AND (R.IDTPIMPOSTOROP = 'CS')
                    GROUP BY R.CDIMPOSTO) LOOP

                    V_NRSEQRELACIT := V_NRSEQRELACIT + 1;

                  INSERT INTO ITRELACITROP
                     (CDFILIAL,  NRROPFILIAL, NRLANCROP, NRITLANCROP, NRSEQRELACITROP,
                      CDITRELITROP, QTITRELITROP, VRITRELITROP)
                  VALUES
                     (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, V_NRSEQRELACIT,
                      C_IMPOSTOCS.CDIMPOSTO, 0, C_IMPOSTOCS.VALORIMPOSTO);

                  V_PRIIMP := 1;
               END LOOP;
            END IF;
         END LOOP;
      END LOOP;

      /* SAIDAS SEM NOTA FISCAL */
      V_DTLANCROP := '01/01/1990';
      FOR C_CONSSAIDA2 IN (SELECT L.CDFILIAL,L.NRLANCESTQ, L.DTLANCESTQ
                            FROM LANCTOESTOQ L, (SELECT DTDATA DIA
                                                   FROM DATA
                                                  WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                            WHERE (L.CDFILIMOVI = P_CDFILIAL)
                              AND (L.IDTPLANCTO = '4')
                              AND (L.DTLANCESTQ = D.DIA)
                              AND (L.NRLANCTONF IS NULL))LOOP

         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_CONSSAIDA2.DTLANCESTQ THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_CONSSAIDA2.DTLANCESTQ;

            V_DTLANCROP   := C_CONSSAIDA2.DTLANCESTQ;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         /*Inclui Lanamento*/
         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
             DTINIREFEROP,  DTFINREFEROP, NUMEROREROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_CONSSAIDA2.DTLANCESTQ, 'SS', '',
             '',  '', '', C_CONSSAIDA2.CDFILIAL,C_CONSSAIDA2.NRLANCESTQ, V_CDFILCENTROP, '', '','','');

         V_NRITLANCROP  := '00000';
         V_NRSEQRELACIT := 0;
         V_PRODUTO      := 'N';
         V_NRSEQIT      := 'N';

         V_PRIIMP := 0;
         FOR C_ITCONSSAIDA2 IN(SELECT AN.CDSUBGRPROD, AN.CDGRUPPROD,SUM(I.VRLANCTOBRUT) AS VALORTOTAL,
                                      SUM(I.QTLANCTOEST) AS QUANTIDADE
                               FROM   ITLANCTOEST I, GRUPPROD GR,SUBGRUPPROD SG, PARFILIALROP P, PRSUBGRPROD AN
                               WHERE (I.CDFILIAL    = C_CONSSAIDA2.CDFILIAL)    AND
                                     (I.NRLANCESTQ   = C_CONSSAIDA2.NRLANCESTQ)  AND
                                     (P.CDFILIAL     = V_FILIALPAR)              AND
                                     (AN.CDFILISUBGR = V_CDFILISUBGR_DRL)        AND
                                     (P.CDGRUPPRODDRL= GR.CDGRUPPROD)            AND
                                     (GR.CDGRUPPROD  = SG.CDGRUPPROD)            AND
                                     (SG.CDSUBGRPROD = AN.CDSUBGRPROD)           AND
                                     (I.CDPRODMOVI   = AN.CDPRODUTO)             AND
                                     (SG.CDGRUPPROD  = AN.CDGRUPPROD)            AND
                                     (NVL(I.IDEVOLESTOQ, 'S') = 'S')
                               GROUP BY AN.CDSUBGRPROD, AN.CDGRUPPROD
                               ORDER BY AN.CDSUBGRPROD, AN.CDGRUPPROD )LOOP

            IF (NVL(V_PRODUTO,'N') <> C_ITCONSSAIDA2.CDSUBGRPROD)THEN

               /*Inclui Item do Lanamento*/
               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');
               V_PRODUTO := C_ITCONSSAIDA2.CDSUBGRPROD;

               INSERT INTO ITLANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                   NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP, VRITEMLANCROP,
                   CDGRUPPRODROP, CDSUBGRPRODROP)
               VALUES
                  (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_CONSSAIDA2.CDFILIAL, C_CONSSAIDA2.NRLANCESTQ,
                   '', C_ITCONSSAIDA2.CDSUBGRPROD,  C_ITCONSSAIDA2.QUANTIDADE, C_ITCONSSAIDA2.VALORTOTAL,
                   C_ITCONSSAIDA2.CDGRUPPROD, C_ITCONSSAIDA2.CDSUBGRPROD);

               V_CONSUMO := V_CONSUMO - C_ITCONSSAIDA2.VALORTOTAL;

            END IF;

         END LOOP;
      END LOOP;
   END IF;
   /* FIM DO CONSUMO SADAS PARA O DRL */

   /* DRF - Implantao e Ajuste para o DRL, usando o grupo de produtos do FORSALE */
   IF (V_IDIMPLANTROP = 'S' OR V_IDAJUSTEROP = 'S') AND (V_IDTPAPURACAO <> '1') THEN
      V_DTLANCROP := '01/01/1990';
      SELECT MAX(CDARVPROD) AS CDPRODFIN,
             MIN(CDARVPROD) AS CDPRODINI
      INTO V_CDPRODFIN, V_CDPRODINI
      FROM PRODUTO P, ITLANCTOEST I, (SELECT DTDATA DIA
                                        FROM DATA
                                       WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
      WHERE CDFILIMOVI  =  P_CDFILIAL    AND
            DTLANCMOVI = D.DIA AND
            I.CDPRODMOVI = P.CDPRODUTO   AND
            IDTIPOMOVI IN ('0','1');

      IF V_CDPRODFIN IS NOT NULL THEN

         SELECT LPAD(ABS(ROUND(DBMS_RANDOM.VALUE(9999,9999999999))),10,'0')
         INTO V_NRMOVIESTQ
         FROM DUAL;

         MOVIMENTACAO_ESTOQUE(P_CDFILIAL,NULL,NULL,NULL, 1, V_DTINIC, P_DTFINAL,  V_CDPRODINI, V_CDPRODFIN, 3, 1,V_NRMOVIESTQ, 'S');

         V_PRODUTO := '';
         V_NRSEQIT := 'N';                         /* ALTERADO PARA GRAVAR POR SUBGRUPO */
         IF V_IDIMPLANTROP = 'S' THEN
            V_DTLANCROP := '01/01/1990';

            FOR C_IMPLANTACAO IN (SELECT AN.CDGRUPPROD, AN.CDSUBGRPROD, DTLANCMOVIEST,
                                         SUM(QTLANCAMENTO) QTLANCAMENTO,
                                         SUM(VRDIFECUST) VRDIFECUST
                                    FROM RELAT_MOVIEST R , PRODUTO P, GRUPPROD GR,
                                         SUBGRUPPROD SG, PARFILIALROP PR,
										 
									( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD ) AN,
                                         
										 (SELECT DTDATA DIA
                                            FROM DATA
                                           WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                                   WHERE (R.CDFILIMOVIEST = P_CDFILIAL)
                                     AND (R.NRRELATMOVI   = V_NRMOVIESTQ)
                                     AND (R.DTLANCMOVIEST = D.DIA)
                                     AND (CDFILISUBGR     = V_CDFILISUBGR_DRL)
                                     AND (PR.CDFILIAL     = V_FILIALPAR)
                                     AND (PR.CDGRUPPRODDRL= GR.CDGRUPPROD)
                                     AND (GR.CDGRUPPROD   = SG.CDGRUPPROD)
                                     AND (SG.CDSUBGRPROD  = AN.CDSUBGRPROD)
                                     AND (P.CDPRODUTO     = AN.CDPRODUTO)
                                     AND (SG.CDGRUPPROD   = AN.CDGRUPPROD)
                                     AND (R.IDTIPOMOVIEST = '0')
                                     AND (CDPRODMOVIEST   = P.CDARVPROD)
                                   GROUP BY DTLANCMOVIEST, AN.CDGRUPPROD, AN.CDSUBGRPROD
                                   ORDER BY DTLANCMOVIEST, AN.CDSUBGRPROD, AN.CDGRUPPROD) LOOP

               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               IF V_DTLANCROP <> C_IMPLANTACAO.DTLANCMOVIEST THEN

                  V_NRROPFILIAL := NULL;
                  SELECT MAX(NRROPFILIAL)
                  INTO V_NRROPFILIAL
                  FROM ROPFILIAL
                  WHERE CDFILIAL    = P_CDFILIAL AND
                        DTFILIALROP = C_IMPLANTACAO.DTLANCMOVIEST;

                  V_DTLANCROP   := C_IMPLANTACAO.DTLANCMOVIEST;
                  IF V_NRROPFILIAL IS NULL THEN
                     V_NRROPFILIAL := V_NRROPFILINI;
                  END IF;

      /* PEGA O ULTIMO NUMERO DO LANAMENTO */
                  SELECT MAX(NRLANCROP)
                    INTO V_NRLANCROP
                    FROM LANCROPFILIAL
                   WHERE CDFILIAL = P_CDFILIAL AND
                         NRROPFILIAL = V_NRROPFILIAL;

                  IF V_NRLANCROP IS NULL THEN
                     V_NRLANCROP  := 0;
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
                  ELSE
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
                  END IF;
               END IF;

                /*Inclui implantao*/
               INSERT INTO LANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                   NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP )
               VALUES
                  (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_IMPLANTACAO.DTLANCMOVIEST, 'IP', '',
                   '',  '', '', '','', V_CDFILCENTROP);

               /*Inclui Item do Lanamento*/
               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

               INSERT INTO ITLANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                   NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP, VRITEMLANCROP,
                   CDGRUPPRODROP, CDSUBGRPRODROP )
               VALUES
                  (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, '', '',
                   '', C_IMPLANTACAO.CDSUBGRPROD,  C_IMPLANTACAO.QTLANCAMENTO, C_IMPLANTACAO.VRDIFECUST,
                   C_IMPLANTACAO.CDGRUPPROD, C_IMPLANTACAO.CDSUBGRPROD);

               V_CONSUMO := V_CONSUMO + C_IMPLANTACAO.VRDIFECUST;
            END LOOP;
         END IF;

         V_PRODUTO := '';
         V_NRSEQIT := 'N';

         IF V_IDAJUSTEROP = 'S' THEN
            V_DTLANCROP := '01/01/1990';
            FOR C_AJUSTE IN (SELECT AN.CDGRUPPROD, AN.CDSUBGRPROD, DTLANCMOVIEST,
                                    SUM(QTLANCAMENTO) QTLANCAMENTO, SUM(VRDIFECUST) VRDIFECUST
                             FROM RELAT_MOVIEST R, PRODUTO  P, GRUPPROD GR,
                                  SUBGRUPPROD SG, PARFILIALROP PR,
								  
								  ( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD ) AN,
                                  
								  (SELECT DTDATA DIA
                                     FROM DATA
                                    WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                             WHERE (R.CDFILIMOVIEST = P_CDFILIAL)
                               AND (R.NRRELATMOVI   = V_NRMOVIESTQ)
                               AND (R.DTLANCMOVIEST = D.DIA)
                               AND (CDFILISUBGR     = V_CDFILISUBGR_DRL)
                               AND (PR.CDFILIAL     = V_FILIALPAR)
                               AND (PR.CDGRUPPRODDRL= GR.CDGRUPPROD)
                               AND (GR.CDGRUPPROD   = SG.CDGRUPPROD)
                               AND (SG.CDSUBGRPROD  = AN.CDSUBGRPROD)
                               AND (P.CDPRODUTO     = AN.CDPRODUTO)
                               AND (SG.CDGRUPPROD   = AN.CDGRUPPROD)
                               AND (R.IDTIPOMOVIEST = '1')
                               AND (CDPRODMOVIEST   = P.CDARVPROD)
                             GROUP BY DTLANCMOVIEST, AN.CDGRUPPROD, AN.CDSUBGRPROD
                             ORDER BY DTLANCMOVIEST, AN.CDSUBGRPROD, AN.CDGRUPPROD) LOOP


               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               IF V_DTLANCROP <> C_AJUSTE.DTLANCMOVIEST THEN

                  V_NRROPFILIAL := NULL;
                  SELECT MAX(NRROPFILIAL)
                  INTO V_NRROPFILIAL
                  FROM ROPFILIAL
                  WHERE CDFILIAL    = P_CDFILIAL AND
                        DTFILIALROP = C_AJUSTE.DTLANCMOVIEST;
                                                                                              
                  V_DTLANCROP   := C_AJUSTE.DTLANCMOVIEST;
                  IF V_NRROPFILIAL IS NULL THEN
                     V_NRROPFILIAL := V_NRROPFILINI;
                  END IF;

      /* PEGA O ULTIMO NUMERO DO LANAMENTO */
                  SELECT MAX(NRLANCROP)
                    INTO V_NRLANCROP
                    FROM LANCROPFILIAL
                   WHERE CDFILIAL = P_CDFILIAL AND
                         NRROPFILIAL = V_NRROPFILIAL;

                  IF V_NRLANCROP IS NULL THEN
                     V_NRLANCROP  := 0;
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
                  ELSE
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
                  END IF;
               END IF;


               /*Inclui ajuste*/
               INSERT INTO LANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                   NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP )
               VALUES
                  (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_AJUSTE.DTLANCMOVIEST, 'A1', '',
                   '',  '', '', '', '', V_CDFILCENTROP);

               /*Inclui Item do Lanamento*/

               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

               INSERT INTO ITLANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                   NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP, VRITEMLANCROP,
                   CDGRUPPRODROP, CDSUBGRPRODROP )
               VALUES
                  (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, '',
                   '', '', C_AJUSTE.CDSUBGRPROD,  C_AJUSTE.QTLANCAMENTO, C_AJUSTE.VRDIFECUST,
                   C_AJUSTE.CDGRUPPROD, C_AJUSTE.CDSUBGRPROD);
            END LOOP;
         END IF;
      END IF;
   END IF;

   /* DRF - CLCULO DA RETIRADA -  RETIRADA DE ESTOQUE - PARA O FORSALE */
   IF (V_IDRETIRADAROP = 'E' OR V_IDRETIRADAROP = 'A') AND (V_IDTPAPURACAO <> '1') THEN
      V_DTLANCROP := '01/01/1990';
      FOR C_RETIRADA IN (SELECT L.CDFILIAL, L.NRLANCESTQ, L.DTLANCESTQ, L.CDFILIMOVI, L.NRLANCTONF
                         FROM   LANCTOESTOQ L, (SELECT DTDATA DIA
                                                  FROM DATA
                                                 WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                         WHERE (L.CDFILIMOVI = P_CDFILIAL  )                   AND
                               (L.DTLANCESTQ = D.DIA)   AND
                               (L.IDTPLANCTO IN ('S','3'))
                         ORDER BY L.NRLANCESTQ,   L.DTLANCESTQ) LOOP

         /*Inclui Retirada de Estoque*/
         V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
         IF V_DTLANCROP <> C_RETIRADA.DTLANCESTQ THEN

            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
            INTO V_NRROPFILIAL
            FROM ROPFILIAL
            WHERE CDFILIAL    = P_CDFILIAL AND
                  DTFILIALROP = C_RETIRADA.DTLANCESTQ;

            V_DTLANCROP   := C_RETIRADA.DTLANCESTQ;
            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

/* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL = P_CDFILIAL AND
                   NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP  := 0;
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;


         V_CONTADOR := 0;
		 V_CDLOJA := '';
         /* VERIFICA SE TEVE VENDA CONSOLIDADA QUE GEROU NOTA */
         IF C_RETIRADA.NRLANCTONF IS NOT NULL THEN
            SELECT COUNT(*) INTO V_CONTADOR
            FROM ITEMVENDA
            WHERE CDFILIALNF = C_RETIRADA.CDFILIAL
              AND NRLANCTONF = C_RETIRADA.NRLANCTONF;

            IF V_CONTADOR = 0 THEN

               /* VERIFICA SE TEVE VENDA CONSOLIDADA SOMENTE POR BAIXA DE ESTOQUE, SEM NOTA FISCAL */
               SELECT COUNT(*) INTO V_CONTADOR
               FROM ITEMVENDA
               WHERE CDFILIALEST = C_RETIRADA.CDFILIAL
                 AND NRLANCESTQ  = C_RETIRADA.NRLANCESTQ;

               IF V_CONTADOR = 0 THEN
                   V_TIPOVENDA := 'R1';  /* OUTRAS RETIRADAS QUE NAO SAO POR CONSOLIDAO */
               ELSE
                   V_TIPOVENDA := 'R2';  /* RETIRADAS POR CONSOLIDAO */
				   SELECT CDLOJA INTO V_CDLOJA
                     FROM ITEMVENDA
                    WHERE CDFILIALEST = C_RETIRADA.CDFILIAL
                      AND NRLANCESTQ  = C_RETIRADA.NRLANCESTQ
                      AND ROWNUM = 1;
               END IF;
            ELSE
               V_TIPOVENDA := 'R2';  /* RETIRADAS POR CONSOLIDAO */
			   SELECT CDLOJA INTO V_CDLOJA
                 FROM ITEMVENDA
                WHERE CDFILIALNF = C_RETIRADA.CDFILIAL
                  AND NRLANCTONF = C_RETIRADA.NRLANCTONF
                  AND ROWNUM = 1;
            END IF;
         ELSE

            /* VERIFICA SE TEVE VENDA CONSOLIDADA SOMENTE POR BAIXA DE ESTOQUE, SEM NOTA FISCAL */
            SELECT COUNT(*) INTO V_CONTADOR
            FROM ITEMVENDA
            WHERE CDFILIALEST = C_RETIRADA.CDFILIAL
              AND NRLANCESTQ  = C_RETIRADA.NRLANCESTQ;

            IF V_CONTADOR = 0 THEN
                V_TIPOVENDA := 'R1';  /* OUTRAS RETIRADAS QUE NAO SAO POR CONSOLIDAO */
            ELSE
                V_TIPOVENDA := 'R2';  /* RETIRADAS POR CONSOLIDAO */
				SELECT CDLOJA INTO V_CDLOJA
                  FROM ITEMVENDA
                 WHERE CDFILIALEST = C_RETIRADA.CDFILIAL
                   AND NRLANCESTQ  = C_RETIRADA.NRLANCESTQ
                   AND ROWNUM = 1;
            END IF;
         END IF;


         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, CDLOJA)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_RETIRADA.DTLANCESTQ, V_TIPOVENDA, '',
             '',  '', '', C_RETIRADA.CDFILIAL, C_RETIRADA.NRLANCESTQ, V_CDFILCENTROP, V_CDLOJA);

            /* VERIFICAR SE AS RETIRADAS DE ESTOQUE  SOFRERAM ALGUMA ALTERACAO QUANTO AO AGRUPAMENTO*/
            FOR C_ITRETIRADA IN(SELECT IT.CDPRODMOVI, AN.CDGRUPPROD, AN.CDSUBGRPROD,
                                  SUM(IT.QTLANCTOEST) AS QTLANCTOEST,
                                  --SUM(IT.VRTOTLANCTO) AS VRLANCTOESTQ
								  SUM(NVL(CUSTO_PRODUTO_LCEST(IT.CDFILIMOVI, IT.CDPRODMOVI, V_NRTIPOCUSTO, IT.DTLANCMOVI, SYSDATE, IT.CDALMOXARIFE, IT.CDLOCALESTOQ,  IT.NRLOTEESTQ, IT.NRSUBLOTE),0) * IT.QTLANCTOEST) AS VRLANCTOESTQ
                                  FROM ITLANCTOEST IT,
								  
								  ( SELECT B.CDPRODUTO,A.CDGRUPPROD,A.CDSUBGRPROD,A.CDFILISUBGR   
                                        FROM PRODUTO B,   
                                             PRODUTO C,        
                                             (SELECT P.CDARVPROD AS CDPRODUTO,   
                                                     N.CDGRUPPROD,   
                                                     N.CDSUBGRPROD,   
                                                     N.CDFILISUBGR    
                                                FROM PRODUTO P,NVSUBGRPROD N   
                                               WHERE P.CDPRODUTO    = N.CDPRODUTO   
                                                 AND N.CDFILISUBGR  = V_CDFILISUBGR_DRL    
                                                 AND N.CDGRUPPROD   = V_CDGRUPPRODDRL) A   
                                      WHERE B.CDPRODUTO    = C.CDPRODUTO   
                                        AND (A.CDFILISUBGR = V_CDFILISUBGR_DRL )   
                                        AND (A.CDGRUPPROD  = V_CDGRUPPRODDRL   )   
                                        AND (C.CDARVPROD  LIKE A.CDPRODUTO||'%')  
                                      ORDER BY B.CDARVPROD ) AN
                                 
								 WHERE (IT.CDFILIAL    = C_RETIRADA.CDFILIAL  )
                                   AND (IT.NRLANCESTQ  = C_RETIRADA.NRLANCESTQ)
                                   AND (NVL(IT.IDEVOLESTOQ, 'S') = 'S')
                                   AND (AN.CDGRUPPROD  = V_CDGRUPPRODDRL)
                                   AND (AN.CDFILISUBGR = V_CDFILISUBGR_DRL)
                                   AND (AN.CDPRODUTO   = IT.CDPRODMOVI )
                                 GROUP BY IT.CDPRODMOVI, AN.CDGRUPPROD, AN.CDSUBGRPROD) LOOP

               /*Inclui Item d Retirada*/
               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

               INSERT INTO ITLANCROPFILIAL
                  (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                   NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP,
                   CDGRUPPRODROP, CDSUBGRPRODROP)
               VALUES
                  (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_RETIRADA.CDFILIAL, C_RETIRADA.NRLANCESTQ,
                   '', C_ITRETIRADA.CDPRODMOVI,  C_ITRETIRADA.QTLANCTOEST, C_ITRETIRADA.VRLANCTOESTQ,
                   C_ITRETIRADA.CDGRUPPROD, C_ITRETIRADA.CDSUBGRPROD);
            END LOOP;
      END LOOP;
   END IF;

/*  1-APURACAO DO DRO DO TECFOOD  2-APURACAO DO DRL DO FORSALE  3-APURACAO DE AMBOS
    A apurao das despesas deve ser feita quando a filial apura somente ForSale, caso o parmetro esteja
    3 a apurao j foi feita no DRO e no  necessria aqui */

   IF V_IDTPAPURACAO = '2' THEN

      /* DRO E DRF - Calculo das Depesas - Lanamentos de Despesas Diversas */
      IF V_IDDESPDIVROP = 'S' THEN
         V_NRITLANCROP := '00000';
         V_DTLANCROP := '01/01/1990';
         FOR C_DESPESASDIV IN (SELECT
                                  D.CDFILIAL, D.CDDESPPREV, D.DTPRDESPFILI,
                                  D.VRPRDESPFILI, D.VRREDESPFILI, IDDESTACAROP
                               FROM
                                  DESPPREVFILI D, DESPPREV E, (SELECT DTDATA DIA
                                                                 FROM DATA
                                                                WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                               WHERE
                                  (D.CDFILIAL     = P_CDFILIAL)          AND
                                  (D.CDDESPPREV   = E.CDDESPPREV)        AND
                                  (D.DTPRDESPFILI = D.DIA)) LOOP


            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            IF V_DTLANCROP <> C_DESPESASDIV.DTPRDESPFILI THEN

               V_NRROPFILIAL := NULL;
               SELECT MAX(NRROPFILIAL)
               INTO V_NRROPFILIAL
               FROM ROPFILIAL
               WHERE CDFILIAL    = P_CDFILIAL AND
                     DTFILIALROP = C_DESPESASDIV.DTPRDESPFILI;

               V_DTLANCROP   := C_DESPESASDIV.DTPRDESPFILI;
               IF V_NRROPFILIAL IS NULL THEN
                  V_NRROPFILIAL := V_NRROPFILINI;
               END IF;

   /* PEGA O ULTIMO NUMERO DO LANAMENTO */
               SELECT MAX(NRLANCROP)
                 INTO V_NRLANCROP
                 FROM LANCROPFILIAL
                WHERE CDFILIAL = P_CDFILIAL AND
                      NRROPFILIAL = V_NRROPFILIAL;

               IF V_NRLANCROP IS NULL THEN
                  V_NRLANCROP  := 0;
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               ELSE
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               END IF;
            END IF;

            /*Inclui Despesas Diversas*/

            IF C_DESPESASDIV.IDDESTACAROP = 'S' THEN
               V_CONSUMO := V_CONSUMO + C_DESPESASDIV.VRREDESPFILI;
            END IF;

            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP,CDFILCENTROP)
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_DESPESASDIV.DTPRDESPFILI, DECODE(C_DESPESASDIV.IDDESTACAROP,  'S','CD','DD'),
                '', '',  '', '', C_DESPESASDIV.CDFILIAL, '', V_CDFILCENTROP);

            V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_DESPESASDIV.CDFILIAL, '',
                '', C_DESPESASDIV.CDDESPPREV,  1, C_DESPESASDIV.VRREDESPFILI);

         END LOOP;
      END IF;

      /* DRO E DRF - LANAMENTOS DE DESPESAS COM MO-DE-OBRA */
      IF V_IDDESPMOBROP= 'S' THEN
         V_DTLANCROP := '01/01/1990';
         V_NRITLANCROP := '00000';
         FOR C_DESPESASMO IN (SELECT L.CDFILIAL, L.DTLANCDESFAT, L.CDDESPADMFAT,
                                     L.VRLANCDESFAT, L.VRTXLANCDESP, L.VRPREVDESFAT
                              FROM LANCDESPFATU L, (SELECT DTDATA DIA
                                                      FROM DATA
                                                     WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                              WHERE (L.CDFILIAL = P_CDFILIAL)                           AND
                                    (L.DTLANCDESFAT = D.DIA)) LOOP


            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            IF V_DTLANCROP <> C_DESPESASMO.DTLANCDESFAT THEN

               V_NRROPFILIAL := NULL;
               SELECT MAX(NRROPFILIAL)
               INTO V_NRROPFILIAL
               FROM ROPFILIAL
               WHERE CDFILIAL    = P_CDFILIAL AND
                     DTFILIALROP = C_DESPESASMO.DTLANCDESFAT;

               V_DTLANCROP   := C_DESPESASMO.DTLANCDESFAT;
               IF V_NRROPFILIAL IS NULL THEN
                  V_NRROPFILIAL := V_NRROPFILINI;
               END IF;

   /* PEGA O ULTIMO NUMERO DO LANAMENTO */
               SELECT MAX(NRLANCROP)
                 INTO V_NRLANCROP
                 FROM LANCROPFILIAL
                WHERE CDFILIAL = P_CDFILIAL AND
                      NRROPFILIAL = V_NRROPFILIAL;

               IF V_NRLANCROP IS NULL THEN
                  V_NRLANCROP  := 0;
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               ELSE
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               END IF;
            END IF;

            /*INCLUI DESPESAS MO DE OBRA*/
            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP)
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_DESPESASMO.DTLANCDESFAT, 'DM', '',
                '',  '', '', C_DESPESASMO.CDFILIAL, '', V_CDFILCENTROP);


            V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_DESPESASMO.CDFILIAL, '',
                '', C_DESPESASMO.CDDESPADMFAT,  1, C_DESPESASMO.VRLANCDESFAT);

         END LOOP;
      END IF;

      /* DRO - LANAMENTOS DE DESPESAS COM COMPRAS */
      IF V_IDDESPENTROP = 'S' THEN
         V_DTLANCROP := '01/01/1990';
         FOR C_DESPCOMPRA IN (SELECT N.CDTIPOOPER, N.NRNOTAFISC, N.CDFILIAL, N.NRLANCTONF,
                                     N.DTENTRSAID, N.CDSERIE, N.CDFORNECED, N.CDFILIRECE,
                                     N.IDSTATUS, N.DTINIREFEFAT, N.DTFINREFEFAT, P_CDFILIAL AS CDFILICCUST
                              FROM TIPOOPERACROP A, NOTAFISCAL N, (SELECT DTDATA DIA
                                                                     FROM DATA
                                                                    WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                              WHERE
                                 (N.CDFILIRECE    = P_CDFILIAL    ) AND
                                 (N.IDENTRSAIDOP  = 'E'           ) AND
                                 (N.DTENTRSAID = D.DIA) AND
                                 (V_FILIALPAR     = A.CDFILIAL    ) AND
                                 (N.CDTIPOOPER    = A.CDTIPOOPER  ) AND
                                 (N.IDENTRSAIDOP  = A.IDENTRSAIDOP) AND
                                 (A.IDTPOPERACROP = 'DE'          ) AND
                                 (N.IDSTATUS      <> 'C'          ) AND
                                 (N.IDSISTEMA NOT IN ('PAG','REC','FIS','CMP') OR N.IDSISTEMA IS NULL)
							  
							  UNION
							  
							  SELECT N.CDTIPOOPER, N.NRNOTAFISC, N.CDFILIAL, N.NRLANCTONF,
                                     N.DTENTRSAID, N.CDSERIE, N.CDFORNECED, N.CDFILIRECE,
                                     N.IDSTATUS, N.DTINIREFEFAT, N.DTFINREFEFAT, R.CDFILICCUST
							    FROM RATEIONF R, ITEMPRODUTO I, TIPOOPERACROP A, NOTAFISCAL N, (SELECT DTDATA DIA
                                                                                           FROM DATA
                                                                                          WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
							   WHERE (R.CDFILICCUST     = P_CDFILIAL    ) AND
							         (N.IDENTRSAIDOP    = 'E'           ) AND
							         (N.DTENTRSAID = D.DIA) AND
									 (V_FILIALPAR       = A.CDFILIAL    ) AND
									 (N.CDTIPOOPER      = A.CDTIPOOPER  ) AND
									 (N.IDENTRSAIDOP    = A.IDENTRSAIDOP) AND
									 (A.IDTPOPERACROP   = 'DE'          ) AND
									 (N.IDSTATUS        <> 'C'          ) AND
							         (N.CDFILIAL        = I.CDFILIAL    ) AND
									 (N.NRLANCTONF      = I.NRLANCTONF  ) AND
									 (R.CDFILIAL        = I.CDFILIAL    ) AND
									 (R.NRLANCTONF      = I.NRLANCTONF  ) AND
									 (R.NRSEQITPROD     = I.NRSEQITPROD ) AND
									 (V_IDCONSPERRATFIL = 'S'           ) AND
									 (N.IDSISTEMA NOT IN ('PAG','REC','FIS','CMP') OR N.IDSISTEMA IS NULL)) LOOP


            V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
            IF V_DTLANCROP <> C_DESPCOMPRA.DTENTRSAID THEN

               V_NRROPFILIAL := NULL;
               SELECT MAX(NRROPFILIAL)
               INTO V_NRROPFILIAL
               FROM ROPFILIAL
               WHERE CDFILIAL    = P_CDFILIAL AND
                     DTFILIALROP = C_DESPCOMPRA.DTENTRSAID;

               V_DTLANCROP   := C_DESPCOMPRA.DTENTRSAID;
               IF V_NRROPFILIAL IS NULL THEN
                  V_NRROPFILIAL := V_NRROPFILINI;
               END IF;

			   /* PEGA O ULTIMO NUMERO DO LANAMENTO */
               SELECT MAX(NRLANCROP)
                 INTO V_NRLANCROP
                 FROM LANCROPFILIAL
                WHERE CDFILIAL = P_CDFILIAL AND
                      NRROPFILIAL = V_NRROPFILIAL;

               IF V_NRLANCROP IS NULL THEN
                  V_NRLANCROP  := 0;
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               ELSE
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               END IF;
            END IF;


            /*Inclui Lanamento*/
            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP, IDSTATUSROP,
                DTINIREFEROP,  DTFINREFEROP)
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_DESPCOMPRA.DTENTRSAID, 'DE', C_DESPCOMPRA.CDFORNECED,
                C_DESPCOMPRA.CDTIPOOPER,  C_DESPCOMPRA.NRNOTAFISC, C_DESPCOMPRA.CDSERIE, C_DESPCOMPRA.CDFILIAL,
                C_DESPCOMPRA.NRLANCTONF, V_CDFILCENTROP, C_DESPCOMPRA.IDSTATUS, C_DESPCOMPRA.DTINIREFEFAT,
                C_DESPCOMPRA.DTFINREFEFAT);

            V_NRITLANCROP := '00000';

            FOR C_ITDESPCOMPRA IN (
                   SELECT DISTINCT I.CDPRODUTO, I.NRSEQITPROD,
								   NVL(DECODE(V_IDCONSPERRATFIL,'S',DECODE(R.VRPERRAT,100,I.VRBRUTITEM,NVL(R.VRRATENF,I.VRBRUTITEM)),I.VRBRUTITEM),0) AS VRRATENF,
                                   I.QTITEMPROD AS QUANTIDADE
                    FROM ITEMPRODUTO I, PRODUTO P, RATEIONF R, PRODFILI PR,
                         (SELECT DISTINCT A.CDPRODUTO
                            FROM PRODUTOROP R, PRODUTO A, PRODUTO B
                           WHERE (INSTR(A.CDARVPROD,B.CDARVPROD) = 1)
                             AND R.CDPRODUTO    = B.CDPRODUTO
                             AND R.CDFILIAL     = V_FILIALPAR
                             AND IDTPPRODUTOROP = 'DE') A
                   WHERE I.CDFILIAL       = C_DESPCOMPRA.CDFILIAL
                     AND I.NRLANCTONF     = C_DESPCOMPRA.NRLANCTONF
                     AND P.CDPRODUTO      = I.CDPRODUTO
                     AND I.CDPRODUTO      = A.CDPRODUTO
					 AND PR.CDFILIAL      = C_DESPCOMPRA.CDFILICCUST
                     AND PR.CDPRODUTO     = I.CDPRODUTO
                     AND NVL(PR.IDCNTRESTOQ, 'N') = 'N'
					 AND R.CDFILICCUST(+) = C_DESPCOMPRA.CDFILICCUST
                     AND R.CDFILIAL   (+) = I.CDFILIAL
                     AND R.NRLANCTONF (+) = I.NRLANCTONF
                     AND R.NRSEQITPROD(+) = I.NRSEQITPROD) LOOP
				
				IF C_ITDESPCOMPRA.VRRATENF > 0 THEN
					/*Inclui Item do Lanamento*/
					V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

					INSERT INTO ITLANCROPFILIAL
						(CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
						 NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP, VRITEMLANCROP)
					VALUES
						(P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), V_NRITLANCROP, C_DESPCOMPRA.CDFILIAL, C_DESPCOMPRA.NRLANCTONF,
						 C_ITDESPCOMPRA.NRSEQITPROD, C_ITDESPCOMPRA.CDPRODUTO, C_ITDESPCOMPRA.QUANTIDADE, C_ITDESPCOMPRA.VRRATENF);
				END IF;
             END LOOP;
         END LOOP;
      END IF;

	  /* Despesas Diversas Lanadas no Contas a Pagar (Considera Rateio) */
      IF V_IDAPUCTPGROP = 'S' THEN
         V_DTLANCROP := '01/01/1990';
         V_NRITLANCROP := '00000';
         FOR C_CONTAPAGAR IN (SELECT CP.CDFILIBPAG, CP.CDFILIAL, CP.NRLANCTONF, CP.NRSEQVENPAG, CP.NRPARCELAPAG, TC.CDTPCTPAGAR,
                                     DECODE(V_IDDTAPUCTPAGAR,'ENTRADA',NF.DTENTRSAID,DECODE(V_IDDTAPUCTPAGAR,'VENCIMENTO',CP.DTATUAVENPAG,DTBAIXAPAG)) AS DTAPURACAO,
									          NVL(R.VRRATCCCTPAG,CP.VRATUAPAG) AS VRCONTARATEADA
                                FROM NOTAFISCAL NF, CONTAPAGAR CP, BOLETPAGAR BO, TIPOCTPAGROP TC, BAIXAPAGA BP, RATCTPAGAR R,
                                     (SELECT DTDATA DIA
                                        FROM DATA
                                       WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                               WHERE CP.CDFILIBPAG     = BO.CDFILIAL
                                 AND CP.NRLANBOLPAG    = BO.NRLANBOLPAG
                                 AND BO.CDFILIBAIPAG   = BP.CDFILIAL  (+)
                                 AND BO.NRBAIXAPAG     = BP.NRBAIXAPAG(+)
                                 AND ((('ENTRADA'      = V_IDDTAPUCTPAGAR) AND (NF.DTENTRSAID   = D.DIA)) OR
                                      (('VENCIMENTO'   = V_IDDTAPUCTPAGAR) AND (CP.DTATUAVENPAG = D.DIA)) OR
                                      (('BAIXA'        = V_IDDTAPUCTPAGAR) AND (BP.DTBAIXAPAG = D.DIA)))
                                 AND TC.CDFILIAL       = V_FILIALPAR
                                 AND TC.CDTPCTPAGAR    = CP.CDTPCTPAGAR
                                 AND TC.IDTPCTPAGROP   = 'DSP'
								         AND NF.CDFILIAL       = CP.CDFILIAL
                                 AND NF.NRLANCTONF     = CP.NRLANCTONF
                                 AND R.CDFILIAL    (+) = CP.CDFILIAL
                                 AND R.NRLANCTONF  (+) = CP.NRLANCTONF
                                 AND R.NRSEQVENPAG (+) = CP.NRSEQVENPAG
                                 AND R.NRPARCELAPAG(+) = CP.NRPARCELAPAG
                                 AND ((R.CDFIRATCTPAG  = P_CDFILIAL) OR ((R.CDFIRATCTPAG IS NULL) AND (NF.CDFILIRECE = P_CDFILIAL)))
                               ORDER BY DTAPURACAO) LOOP

            V_NRLANCROP:= LPAD(V_NRLANCROP + 1,10,'0');

            /* IF V_DTLANCROP <> C_CONTAPAGAR.DTBAIXAPAG THEN */

               V_NRROPFILIAL := NULL;

               SELECT MAX(NRROPFILIAL)
               INTO V_NRROPFILIAL
               FROM ROPFILIAL
               WHERE CDFILIAL    = P_CDFILIAL AND
                     DTFILIALROP = C_CONTAPAGAR.DTAPURACAO;


               V_DTLANCROP   := C_CONTAPAGAR.DTAPURACAO;
              /* IF V_NRROPFILIAL IS NULL THEN
                  V_NRROPFILIAL := V_NRROPFILINI;
               END IF; */

               /* PEGA O ULTIMO NUMERO DO LANAMENTO */
               SELECT MAX(NRLANCROP)
                 INTO V_NRLANCROP
                 FROM LANCROPFILIAL
                WHERE CDFILIAL = P_CDFILIAL AND
                      NRROPFILIAL = V_NRROPFILIAL;

               IF V_NRLANCROP IS NULL THEN
                  V_NRLANCROP  := 0;
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               ELSE
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               END IF;
            /* END IF; */

            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, NRSEQVENPAGROP, NRPARCELAPAGROP, CDFILCENTROP)
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_CONTAPAGAR.DTAPURACAO, 'DC', '', '',
               '', '', C_CONTAPAGAR.CDFILIAL, C_CONTAPAGAR.NRLANCTONF, C_CONTAPAGAR.NRSEQVENPAG, C_CONTAPAGAR.NRPARCELAPAG, V_CDFILCENTPME);


            V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP,    VRITEMLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'),   LPAD(V_NRITLANCROP,5,'0'), '', '',
                '',  C_CONTAPAGAR.CDTPCTPAGAR,  1, C_CONTAPAGAR.VRCONTARATEADA);
         END LOOP;
      END IF;
      
      /* Despesas com Mo de Obra Lanadas no Contas a Pagar (Considera Rateio) */
      IF V_IDAPUMOCTPGROP = 'S' THEN
         V_DTLANCROP := '01/01/1990';
         V_NRITLANCROP := '00000';
         FOR C_CTPAGMOBRA IN (SELECT CP.CDFILIBPAG, CP.CDFILIAL, CP.NRLANCTONF, CP.NRSEQVENPAG, CP.NRPARCELAPAG, TC.CDTPCTPAGAR,
                                     DECODE(V_IDDTAPUCTPAGAR,'ENTRADA',NF.DTENTRSAID,DECODE(V_IDDTAPUCTPAGAR,'VENCIMENTO',CP.DTATUAVENPAG,DTBAIXAPAG)) AS DTAPURACAO,
									          NVL(R.VRRATCCCTPAG,CP.VRATUAPAG) AS VRCONTARATEADA
                                FROM NOTAFISCAL NF, CONTAPAGAR CP, BOLETPAGAR BO, TIPOCTPAGROP TC, BAIXAPAGA BP, RATCTPAGAR R,
                                    (SELECT DTDATA DIA
                                       FROM DATA
                                      WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                               WHERE CP.CDFILIBPAG     = BO.CDFILIAL
                                 AND CP.NRLANBOLPAG    = BO.NRLANBOLPAG
                                 AND BO.CDFILIBAIPAG   = BP.CDFILIAL  (+)
                                 AND BO.NRBAIXAPAG     = BP.NRBAIXAPAG(+)
                                 AND ((('ENTRADA'      = V_IDDTAPUCTPAGAR) AND (NF.DTENTRSAID   = D.DIA)) OR
                                      (('VENCIMENTO'   = V_IDDTAPUCTPAGAR) AND (CP.DTATUAVENPAG = D.DIA)) OR
                                      (('BAIXA'        = V_IDDTAPUCTPAGAR) AND (BP.DTBAIXAPAG  = D.DIA)))
                                 AND TC.CDFILIAL       = V_FILIALPAR
                                 AND TC.CDTPCTPAGAR    = CP.CDTPCTPAGAR
                                 AND TC.IDTPCTPAGROP   = 'MAO'
								         AND NF.CDFILIAL       = CP.CDFILIAL
                                 AND NF.NRLANCTONF     = CP.NRLANCTONF
								         AND R.CDFILIAL    (+) = CP.CDFILIAL
                                 AND R.NRLANCTONF  (+) = CP.NRLANCTONF
                                 AND R.NRSEQVENPAG (+) = CP.NRSEQVENPAG
                                 AND R.NRPARCELAPAG(+) = CP.NRPARCELAPAG
								         AND ((R.CDFIRATCTPAG  = P_CDFILIAL) OR ((R.CDFIRATCTPAG IS NULL) AND (NF.CDFILIRECE = P_CDFILIAL)))
                               ORDER BY DTAPURACAO) LOOP

            V_NRLANCROP:= LPAD(V_NRLANCROP + 1,10,'0');

               V_NRROPFILIAL := NULL;

               SELECT MAX(NRROPFILIAL)
               INTO V_NRROPFILIAL
               FROM ROPFILIAL
               WHERE CDFILIAL    = P_CDFILIAL AND
                     DTFILIALROP = C_CTPAGMOBRA.DTAPURACAO;


               V_DTLANCROP   := C_CTPAGMOBRA.DTAPURACAO;

               /* PEGA O ULTIMO NUMERO DO LANAMENTO */
               SELECT MAX(NRLANCROP)
                 INTO V_NRLANCROP
                 FROM LANCROPFILIAL
                WHERE CDFILIAL = P_CDFILIAL AND
                      NRROPFILIAL = V_NRROPFILIAL;

               IF V_NRLANCROP IS NULL THEN
                  V_NRLANCROP  := 0;
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               ELSE
                  V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0');
               END IF;

            INSERT INTO LANCROPFILIAL
               (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
                NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, NRSEQVENPAGROP, NRPARCELAPAGROP, CDFILCENTROP)
            VALUES
               (P_CDFILIAL, V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'), C_CTPAGMOBRA.DTAPURACAO, 'DM', '', '',
               '', '', C_CTPAGMOBRA.CDFILIAL, C_CTPAGMOBRA.NRLANCTONF, C_CTPAGMOBRA.NRSEQVENPAG, C_CTPAGMOBRA.NRPARCELAPAG, V_CDFILCENTPME);


            V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

            INSERT INTO ITLANCROPFILIAL
               (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
                NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP,    VRITEMLANCROP)
            VALUES
               (P_CDFILIAL,  V_NRROPFILIAL, LPAD(V_NRLANCROP,10,'0'),   LPAD(V_NRITLANCROP,5,'0'), '', '',
                '',  C_CTPAGMOBRA.CDTPCTPAGAR,  1, C_CTPAGMOBRA.VRCONTARATEADA);
         END LOOP;
      END IF;
      
      /* Despesas com Mo de Obra Lanadas no Contabilidade */             
      IF V_IDDESPMOBROPCTB = 'S' THEN
         V_DTLANCROP := '01/01/1990';
         V_NRITLANCROP := '00000';
         IF V_DTINIC < P_DTINICIAL THEN
           V_DTFOLHA  := P_DTINICIAL;
         ELSE
           V_DTFOLHA := V_DTINIC ;
         END IF;   
         FOR C_FOLHA IN( SELECT CDFILIAL, CDCONTCTBL, CDDESPADMFAT 
                           FROM DESPORCMOCCONT 
                          WHERE ((CDFILIAL = P_CDFILIAL) OR (CDFILIAL = 'T')) 
                            AND CDDESPADMFAT = '06') LOOP 
            FOR C_LANCCUST IN( SELECT ROUND(SUM(VRLANCCUST),2) VRLANC 
                                 FROM LANCCCUSTO 
                                WHERE CDEMPRESA   = V_CDEMPRESA 
                                  AND CDFILIAL    = P_CDFILIAL 
                                  AND CDCONTCTBL  = C_FOLHA.CDCONTCTBL 
                                  AND TO_CHAR(DTCOMPCUSTO,'MMYYYY') = TO_CHAR(V_DTFOLHA,'MMYYYY')) LOOP 
               V_NRLANCROP:= LPAD(V_NRLANCROP + 1,10,'0'); 
               IF V_DTLANCROP <> V_DTINIC THEN 
                  V_NRROPFILIAL := NULL; 
                  SELECT MAX(NRROPFILIAL) 
                  INTO V_NRROPFILIAL 
                  FROM ROPFILIAL 
                  WHERE CDFILIAL    = P_CDFILIAL AND 
                        DTFILIALROP = V_DTINIC; 
                  V_DTLANCROP   := V_DTINIC; 
                  IF V_NRROPFILIAL IS NULL THEN 
                     V_NRROPFILIAL := V_NRROPFILINI; 
                  END IF; 
                  SELECT MAX(NRLANCROP) 
                    INTO V_NRLANCROP 
                    FROM LANCROPFILIAL 
                   WHERE CDFILIAL = P_CDFILIAL AND 
                         NRROPFILIAL = V_NRROPFILIAL; 
                  IF V_NRLANCROP IS NULL THEN 
                     V_NRLANCROP  := 0; 
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0'); 
                  ELSE 
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0'); 
                  END IF; 
               END IF;
               INSERT INTO LANCROPFILIAL 
                  (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP, 
                   NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP) 
               VALUES 
                  (P_CDFILIAL, V_NRROPFILIAL, V_NRLANCROP,V_DTFOLHA, 'DM', '', 
                   '',  '', '', C_FOLHA.CDFILIAL, '', V_CDFILCENTPME); 
               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0'); 
               IF C_LANCCUST.VRLANC > 0 THEN 
                  INSERT INTO ITLANCROPFILIAL 
                     (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP, 
                      NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP) 
                  VALUES 
                     (P_CDFILIAL,  V_NRROPFILIAL, V_NRLANCROP, V_NRITLANCROP, C_FOLHA.CDFILIAL, '', 
                      '', C_FOLHA.CDDESPADMFAT,  1, -C_LANCCUST.VRLANC); 
               ELSE 
                  INSERT INTO ITLANCROPFILIAL 
                     (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP, 
                      NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP) 
                  VALUES 
                     (P_CDFILIAL,  V_NRROPFILIAL, V_NRLANCROP, V_NRITLANCROP, C_FOLHA.CDFILIAL, 'CTB',
                      /*Adicionado a string CTB ao campo NRLANCTONFITROP apenas para diferenciar o lanamento entre contabil e manual*/ 
                      '', C_FOLHA.CDDESPADMFAT,  1, ABS(C_LANCCUST.VRLANC)); 
               END IF;        
            END LOOP; 
         END LOOP; 
         FOR C_FOLHA IN( SELECT CDFILIAL, CDCONTCTBL, CDDESPADMFAT 
                           FROM DESPORCMOCCONT 
                          WHERE ((CDFILIAL = P_CDFILIAL) OR (CDFILIAL = 'T')) 
                            AND CDDESPADMFAT <> '06') LOOP 
            FOR C_LANCCUST IN(          
             SELECT VRLANC FROM(
				SELECT ROUND(SUM(VRLANCCUST),2) VRLANC
				  FROM LANCCCUSTO
				 WHERE CDFILIAL    = P_CDFILIAL
				   AND CDCONTCTBL  = C_FOLHA.CDCONTCTBL
                   AND TO_CHAR(TO_DATE(DTCOMPCUSTO),'MMYYYY') = TO_CHAR(TO_DATE(V_DTFOLHA),'MMYYYY'))) LOOP 
               V_NRLANCROP:= LPAD(V_NRLANCROP + 1,10,'0'); 
               IF V_DTLANCROP <> V_DTINIC THEN 
                  V_NRROPFILIAL := NULL; 
                  SELECT MAX(NRROPFILIAL) 
                  INTO V_NRROPFILIAL 
                  FROM ROPFILIAL 
                  WHERE CDFILIAL    = P_CDFILIAL AND 
                        DTFILIALROP = V_DTINIC; 
                  V_DTLANCROP   := V_DTINIC; 
                  IF V_NRROPFILIAL IS NULL THEN 
                     V_NRROPFILIAL := V_NRROPFILINI; 
                  END IF; 
                  SELECT MAX(NRLANCROP) 
                    INTO V_NRLANCROP 
                    FROM LANCROPFILIAL 
                   WHERE CDFILIAL = P_CDFILIAL AND 
                         NRROPFILIAL = V_NRROPFILIAL; 
                  IF V_NRLANCROP IS NULL THEN 
                     V_NRLANCROP  := 0; 
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0'); 
                  ELSE 
                     V_NRLANCROP  := LPAD(V_NRLANCROP + 1,10,'0'); 
                  END IF; 
               END IF; 
               /*Insere os lanamentos*/ 
               INSERT INTO LANCROPFILIAL 
                  (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP, 
                   NRNOTAFISCROP,    CDSERIENFROP,    CDFILIALNFROP,    NRLANCTONFROP, CDFILCENTROP) 
               VALUES 
                  (P_CDFILIAL, V_NRROPFILIAL, V_NRLANCROP, V_DTFOLHA, 'DM', '', 
                   '',  '', '', C_FOLHA.CDFILIAL, '', V_CDFILCENTPME); 
               V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0'); 
               /*Insere os itens do lanamento*/
               INSERT INTO ITLANCROPFILIAL 
                  (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP, 
                   NRSEQITPRODROP, CDITEMLANCROP,QTITEMLANCROP,    VRITEMLANCROP) 
               VALUES 
                  (P_CDFILIAL,  V_NRROPFILIAL, V_NRLANCROP, V_NRITLANCROP, C_FOLHA.CDFILIAL, 'CTB', 
                   /*Adicionado a string CTB ao campo NRLANCTONFITROP apenas para diferenciar o lanamento entre contabil e manual*/ 
                   '', C_FOLHA.CDDESPADMFAT,  1, C_LANCCUST.VRLANC); 
            END LOOP;         
         END LOOP;      
      END IF;
   END IF;
   
   /* Lanamentos de Investimento (Manual) */
   IF (V_IDAPUINVFILROP = 'S') and (V_IDTPAPURACAO = '2') THEN
      V_DTLANCROP   := '01/01/1990';
      V_NRITLANCROP := '00000';
      FOR C_LANCINVEFILI IN (SELECT CDINVEST, DTINVEFILI, VRINVEFILI, CDFILIAL
                               FROM LANCINVEFILI, (SELECT DTDATA DIA
                                                     FROM DATA
                                                    WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                              WHERE CDFILIAL = P_CDFILIAL
                                AND DTINVEFILI = D.DIA) LOOP
         V_NRLANCROP := LPAD(V_NRLANCROP + 1,10,'0');

         IF V_DTLANCROP <> C_LANCINVEFILI.DTINVEFILI THEN
            V_NRROPFILIAL := NULL;

            SELECT MAX(NRROPFILIAL)
              INTO V_NRROPFILIAL
              FROM ROPFILIAL
             WHERE CDFILIAL    = P_CDFILIAL
               AND DTFILIALROP = C_LANCINVEFILI.DTINVEFILI;

            V_DTLANCROP := C_LANCINVEFILI.DTINVEFILI;

            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

            /* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL    = P_CDFILIAL
               AND NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP := 0;
               V_NRLANCROP := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP, CDFILIALNFROP, NRLANCTONFROP, CDFILCENTROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, V_NRLANCROP, C_LANCINVEFILI.DTINVEFILI, 'IV', '',
             '', '', '', C_LANCINVEFILI.CDFILIAL, '', V_CDFILCENTPME);

         V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP, VRITEMLANCROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, V_NRLANCROP, V_NRITLANCROP, C_LANCINVEFILI.CDFILIAL, '',
             '', C_LANCINVEFILI.CDINVEST, 1, C_LANCINVEFILI.VRINVEFILI);
      END LOOP;
   END IF;
   
   /* Lanamentos de Investimentos no Contas a Pagar */
   IF (V_IDAPURAINVCTPAGROP = 'S') and (V_IDTPAPURACAO = '2') THEN
      FOR C_CTPAGINV IN(SELECT CP.IDSTATPAG, CP.CDFILIBPAG, CP.CDFILIAL, CP.NRLANCTONF, CP.NRSEQVENPAG, CP.NRPARCELAPAG,
                               TC.CDTPCTPAGAR, CP.DTATUAVENPAG AS DTBAIXAPAG, NVL(R.VRRATCCCTPAG,CP.VRATUAPAG) AS VRCONTARATEADA
                         FROM CONTAPAGAR CP,NOTAFISCAL NF, BOLETPAGAR BO, BAIXAPAGA BP, TIPOCTPAGROP TC, RATCTPAGAR R,
                              (SELECT DTDATA DIA
                                 FROM DATA
                                WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
                        WHERE CP.CDFILIBPAG     = BO.CDFILIAL
                          AND CP.NRLANBOLPAG    = BO.NRLANBOLPAG
                          AND BO.CDFILIBAIPAG   = BP.CDFILIAL  (+)
                          AND BO.NRBAIXAPAG     = BP.NRBAIXAPAG(+)
                          AND (CP.DTATUAVENPAG = D.DIA)
                          AND TC.CDFILIAL       = V_FILIALPAR
                          AND TC.CDTPCTPAGAR    = CP.CDTPCTPAGAR
                          AND TC.IDTPCTPAGROP   = 'INV'
                          AND NF.CDFILIAL       = CP.CDFILIAL
                          AND NF.NRLANCTONF     = CP.NRLANCTONF
                          AND R.CDFILIAL    (+) = CP.CDFILIAL
                          AND R.NRLANCTONF  (+) = CP.NRLANCTONF
                          AND R.NRSEQVENPAG (+) = CP.NRSEQVENPAG
                          AND R.NRPARCELAPAG(+) = CP.NRPARCELAPAG
                          AND ((R.CDFIRATCTPAG    = P_CDFILIAL) OR ((R.CDFIRATCTPAG IS NULL) AND (NF.CDFILIRECE = P_CDFILIAL)))
                        ORDER BY CP.DTATUAVENPAG) LOOP
         V_NRLANCROP := LPAD(V_NRLANCROP + 1,10,'0');

         IF V_DTLANCROP <> C_CTPAGINV.DTBAIXAPAG THEN
            V_NRROPFILIAL := NULL;
            SELECT MAX(NRROPFILIAL)
              INTO V_NRROPFILIAL
              FROM ROPFILIAL
             WHERE CDFILIAL    = P_CDFILIAL
               AND DTFILIALROP = C_CTPAGINV.DTBAIXAPAG;

            V_DTLANCROP := C_CTPAGINV.DTBAIXAPAG;

            IF V_NRROPFILIAL IS NULL THEN
               V_NRROPFILIAL := V_NRROPFILINI;
            END IF;

            /* PEGA O ULTIMO NUMERO DO LANAMENTO */
            SELECT MAX(NRLANCROP)
              INTO V_NRLANCROP
              FROM LANCROPFILIAL
             WHERE CDFILIAL    = P_CDFILIAL
               AND NRROPFILIAL = V_NRROPFILIAL;

            IF V_NRLANCROP IS NULL THEN
               V_NRLANCROP := 0;
               V_NRLANCROP := LPAD(V_NRLANCROP + 1,10,'0');
            ELSE
               V_NRLANCROP := LPAD(V_NRLANCROP + 1,10,'0');
            END IF;
         END IF;

         INSERT INTO LANCROPFILIAL
            (CDFILIAL, NRROPFILIAL,  NRLANCROP,  DTLANCROP, IDTPLANCROP, CDCLIENTEROP, CDTIPOOPERROP,
             NRNOTAFISCROP, CDSERIENFROP, CDFILIALNFROP, NRLANCTONFROP, NRSEQVENPAGROP, NRPARCELAPAGROP, CDFILCENTROP)
         VALUES
            (P_CDFILIAL, V_NRROPFILIAL, V_NRLANCROP, C_CTPAGINV.DTBAIXAPAG, 'IV', '', '',
            '', '', C_CTPAGINV.CDFILIAL, C_CTPAGINV.NRLANCTONF, C_CTPAGINV.NRSEQVENPAG, C_CTPAGINV.NRPARCELAPAG, V_CDFILCENTPME);

         V_NRITLANCROP := LPAD(V_NRITLANCROP + 1,5,'0');

         INSERT INTO ITLANCROPFILIAL
            (CDFILIAL, NRROPFILIAL, NRLANCROP, NRITLANCROP, CDFILIALNFITROP, NRLANCTONFITROP,
             NRSEQITPRODROP, CDITEMLANCROP, QTITEMLANCROP, VRITEMLANCROP)
         VALUES
            (P_CDFILIAL,  V_NRROPFILIAL, V_NRLANCROP, V_NRITLANCROP, '', '',
             '', C_CTPAGINV.CDTPCTPAGAR, 1, C_CTPAGINV.VRCONTARATEADA);
      END LOOP;
   END IF;

   DELETE FROM RELAT_MOVIEST
   WHERE
      (CDFILIMOVIEST = P_CDFILIAL)      AND
      (NRRELATMOVI   = V_NRMOVIESTQ);

   /* APURAO DO CONSUMO -  PERODO CONSUMO = CONSIDERA CONSUMO ANTERIOR */
   V_DTINICIO := V_DTINIC;
   V_DTFINAL  := V_DTINIC;
   IF (V_IDPERCONSROP = 'P') AND  (V_NRMESCONSROP > 1) AND (P_IDCONSANT = 'N')  THEN
      V_NRCOUNT   := 1;
      WHILE (V_NRCOUNT < V_NRMESCONSROP) LOOP

         SELECT '01/'||DECODE(TO_CHAR(V_DTINICIO, 'MM') , '01', '12/'||TO_CHAR(TO_NUMBER(TO_CHAR(V_DTINICIO, 'YYYY'))-1), LPAD(TO_NUMBER(TO_CHAR(V_DTINICIO, 'MM')) - 1, 2,'0')||'/'|| TO_CHAR(V_DTINICIO, 'YYYY'))
         INTO V_DTINICIO
         FROM DUAL;
         V_DTFINAL := LAST_DAY(TO_DATE(V_DTINICIO));

         V_NRCONS := 0;
         SELECT COUNT(*)
           INTO V_NRCONS
           FROM ROPFILIAL, (SELECT DTDATA DIA
                               FROM DATA
                              WHERE DTDATA BETWEEN V_DTINIC AND P_DTFINAL) D
          WHERE CDFILIAL = P_CDFILIAL
            AND DTFILIALROP = D.DIA;
         IF NVL(V_NRCONS,0)  = 0 THEN
            APURAC_RESOPERFILI(P_CDFILIAL, V_DTINICIO, V_DTFINAL, 'S');
         END IF;

         V_NRCOUNT := V_NRCOUNT + 1;
      END LOOP;
   END IF;

   IF V_IDFECHDIAROP = 'S'  THEN
      UPDATE APURACAOROP
      SET DTINIAPURACROP  = P_DTFINAL + 1,
          DTFINAPURACROP  = P_DTFINAL + 1
      WHERE CDFILIAL = P_CDFILIAL;
   END IF;

END;
/
